@@ -108,6 +108,9 @@ BitcoinGUI::BitcoinGUI(interfaces::Node& node, const PlatformStyle *_platformSty
     {
         /** Create wallet frame and make it the central widget */
         walletFrame = new WalletFrame(_platformStyle, this);
+        connect(walletFrame, &WalletFrame::message, [this](const QString& title, const QString& message, unsigned int style) {
+            this->message(title, message, style);
+        });
         setCentralWidget(walletFrame);
     } else
 #endif // ENABLE_WALLET
@@ -166,7 +169,9 @@ BitcoinGUI::BitcoinGUI(interfaces::Node& node, const PlatformStyle *_platformSty
         frameBlocksLayout->addWidget(unitDisplayControl);
         frameBlocksLayout->addStretch();
         frameBlocksLayout->addWidget(labelWalletEncryptionIcon);
+        labelWalletEncryptionIcon->hide();
         frameBlocksLayout->addWidget(labelWalletHDStatusIcon);
+        labelWalletHDStatusIcon->hide();
     }
     frameBlocksLayout->addWidget(labelProxyIcon);
     frameBlocksLayout->addStretch();
@@ -549,7 +554,9 @@ void BitcoinGUI::createMenuBar()
         window_menu->addAction(usedReceivingAddressesAction);
     }
 
+    window_menu->addSeparator();
     window_menu->addAction(m_show_netwatch_action);
+    window_menu->addAction(showMempoolStatsAction);
 
     window_menu->addSeparator();
     for (RPCConsole::TabTypes tab_type : rpcConsole->tabs()) {
@@ -560,7 +567,6 @@ void BitcoinGUI::createMenuBar()
             showDebugWindow();
         });
     }
-    window_menu->addAction(showMempoolStatsAction);
 
     QMenu *help = appMenuBar->addMenu(tr("&Help"));
     help->addAction(showHelpMessageAction);
@@ -1010,20 +1016,23 @@ void BitcoinGUI::setNetworkActive(bool networkActive)
 {
     updateNetworkState();
     m_network_context_menu->clear();
-    m_network_context_menu->addAction(
+    QAction* const show_peers_action = m_network_context_menu->addAction(
         //: A context menu item. The "Peers tab" is an element of the "Node window".
-        tr("Show Peers tab"),
+        tr("Show Peers tab"));
+    connect(show_peers_action, &QAction::triggered,
         [this] {
             rpcConsole->setTabFocus(RPCConsole::TabTypes::PEERS);
             showDebugWindow();
         });
-    m_network_context_menu->addAction(
+    QAction* const enabledisable_action = m_network_context_menu->addAction(
         networkActive ?
             //: A context menu item.
             tr("Disable network activity") :
             //: A context menu item. The network activity was disabled previously.
-            tr("Enable network activity"),
-        [this, new_state = !networkActive] { m_node.setNetworkActive(new_state); });
+            tr("Enable network activity"));
+    const bool new_state = !networkActive;
+    connect(enabledisable_action, &QAction::triggered,
+        [this, new_state] { m_node.setNetworkActive(new_state); });
 }
 
 void BitcoinGUI::updateHeadersSyncProgressLabel()
