@@ -444,6 +444,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>ዋሌት</translation>
+    </message>
     <message>
         <source>Wallet Name</source>
         <translation>ዋሌት ስም</translation>
@@ -537,6 +541,11 @@
         <source>default wallet</source>
         <translation>መደበኛ ዋሌት</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>ዋሌት ክፈት</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -544,6 +553,10 @@
         <source>Options</source>
         <translation type="unfinished">አማራጮች</translation>
     </message>
+    <message>
+        <source>W&amp;allet</source>
+        <translation type="unfinished">&amp;ዋሌት</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>ስህተት</translation>
@@ -810,7 +823,11 @@
         <source>Create a new wallet</source>
         <translation>አዲስ ዋሌት ፍጠር</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>ስህተት</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -828,10 +845,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>ስህተት</translation>
-    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
