@@ -23,7 +23,7 @@
     </message>
     <message>
         <source>Delete the currently selected address from the list</source>
-        <translation>Hazırki seçilmiş ünvanı siyahıdan sil</translation>
+        <translation>Hazırki seçilmiş ünvanı siyahıdan silin</translation>
     </message>
     <message>
         <source>Enter address or label to search</source>
@@ -63,7 +63,7 @@
     </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
-        <translation>Bunlar ödənişləri göndərmək üçün Bitcoin ünvanlarınızdır. pul göndərməzdən əvvəl həmişə miqdarı və göndəriləcək ünvanı yoxlayın.</translation>
+        <translation>Bunlar ödənişləri göndərmək üçün Bitcoin ünvanlarınızdır. Pul göndərməkdən əvvəl həmişə miqdarı və göndəriləcək ünvanı yoxlayın.</translation>
     </message>
     <message>
         <source>&amp;Copy Address</source>
@@ -133,23 +133,23 @@
     </message>
     <message>
         <source>Encrypt wallet</source>
-        <translation>Şifrəli pulqabı</translation>
+        <translation>Cüzdanı şifrələyin</translation>
     </message>
     <message>
         <source>This operation needs your wallet passphrase to unlock the wallet.</source>
-        <translation>Bu əməliyyatın pulqabı kilidini açılması üçün pul qabınızın şifrə ifadəsinə ehtiyacı var.</translation>
+        <translation>Bu əməliyyat, cüzdanın kilidini açmaq üçün cüzdan şifrə ifadəsinə ehtiyac duyur.</translation>
     </message>
     <message>
         <source>Unlock wallet</source>
-        <translation>Pulqabı kilidini aç</translation>
+        <translation>Cüzdanın kilidini açın</translation>
     </message>
     <message>
         <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
-        <translation>Bu əməliyyatın pulqabı şifrəsini açmaq üçün pul qabınızın şifrə ifadəsinə ehtiyacı var.</translation>
+        <translation>Bu əməliyyat, cüzdanın şifrəsini açmaq üçün cüzdan şifrə ifadəsinə ehtiyac duyur.</translation>
     </message>
     <message>
         <source>Decrypt wallet</source>
-        <translation>Pulqabı şifrəsini aç</translation>
+        <translation>Cüzdanın şifrəsini açın</translation>
     </message>
     <message>
         <source>Change passphrase</source>
@@ -157,11 +157,42 @@
     </message>
     <message>
         <source>Confirm wallet encryption</source>
-        <translation>Pulqabı şifrələməsini təsdiqlə</translation>
+        <translation>Cüzdan şifrələməsini təsdiqləyin</translation>
     </message>
+    <message>
+        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
+        <translation>Unutmayın ki, cüzdanınızın şifrələməsi bitcoinlərinizi kompüterinizə zərərli proqram tərəfindən oğurlanmaqdan tamamilə qoruya bilməz.</translation>
+    </message>
+    <message>
+        <source>Wallet to be encrypted</source>
+        <translation>Cüzdan şifrələnəcək</translation>
+    </message>
+    <message>
+        <source>Your wallet is about to be encrypted. </source>
+        <translation>Cüzdanınız şifrələnmək üzrədir.</translation>
+    </message>
+    <message>
+        <source>Your wallet is now encrypted. </source>
+        <translation>Cüzdanınız artıq şifrələnib.</translation>
+    </message>
+    <message>
+        <source>Warning: The Caps Lock key is on!</source>
+        <translation>Xəbərdarlıq: Caps Lock düyməsi yanılıdır!</translation>
+    </message>
+</context>
+<context>
+    <name>BanTableModel</name>
     </context>
 <context>
     <name>BitcoinGUI</name>
+    <message>
+        <source>&amp;Encrypt Wallet...</source>
+        <translation type="unfinished">&amp;Şifrəli pulqabı...</translation>
+    </message>
+    <message>
+        <source>Open &amp;URI...</source>
+        <translation>&amp;URI aç...</translation>
+    </message>
     <message>
         <source>&amp;Settings</source>
         <translation>&amp;Tənzimləmələr</translation>
@@ -201,11 +232,22 @@
         <source>Copy &amp;label</source>
         <translation>&amp;Etiketi kopyala</translation>
     </message>
+    <message>
+        <source>Copy quantity</source>
+        <translation>Miqdarı kopyalayın</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Dəyişikliyi kopyalayın</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(etiket yoxdur)</translation>
     </message>
     </context>
+<context>
+    <name>CreateWalletActivity</name>
+    </context>
 <context>
     <name>CreateWalletDialog</name>
     <message>
@@ -224,6 +266,12 @@
         <translation type="unfinished">&amp;Ünvan</translation>
     </message>
     </context>
+<context>
+    <name>FreespaceChecker</name>
+    </context>
+<context>
+    <name>HelpMessageDialog</name>
+    </context>
 <context>
     <name>Intro</name>
     <message>
@@ -235,6 +283,9 @@
         <translation>Xəta</translation>
     </message>
     </context>
+<context>
+    <name>ModalOverlay</name>
+    </context>
 <context>
     <name>NetWatchLogModel</name>
     <message>
@@ -243,6 +294,12 @@
         <translation>Ünvan</translation>
     </message>
 </context>
+<context>
+    <name>OpenURIDialog</name>
+    </context>
+<context>
+    <name>OpenWalletActivity</name>
+    </context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -253,6 +310,10 @@
         <source>Reverting this setting requires re-downloading the entire blockchain.</source>
         <translation>Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. </translation>
     </message>
+    <message>
+        <source>Map port using &amp;UPnP</source>
+        <translation>&amp;UPnP istifadə edən xəritə portu</translation>
+    </message>
     <message>
         <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
         <translation>İstifadəçi interfeys dili burada tənzimlənə bilər. Bu tənzimləmə %1 yenidən başladıldıqdan sonra təsirli olacaq.</translation>
@@ -262,6 +323,9 @@
         <translation>Xəta</translation>
     </message>
     </context>
+<context>
+    <name>OverviewPage</name>
+    </context>
 <context>
     <name>PSBTOperationsDialog</name>
     <message>
@@ -269,12 +333,31 @@
         <translation type="unfinished">Bağla</translation>
     </message>
     </context>
+<context>
+    <name>PairingPage</name>
+    </context>
+<context>
+    <name>PaymentServer</name>
+    </context>
+<context>
+    <name>PeerTableModel</name>
+    </context>
+<context>
+    <name>QObject</name>
+    </context>
+<context>
+    <name>QRImageWidget</name>
+    </context>
 <context>
     <name>RPCConsole</name>
     <message>
         <source>&amp;Information</source>
         <translation type="unfinished">&amp;Məlumat</translation>
     </message>
+    <message>
+        <source>&amp;Reset</source>
+        <translation>&amp;Sıfırla</translation>
+    </message>
     <message>
         <source>&amp;Copy address</source>
         <extracomment>Context menu action to copy the address of a peer</extracomment>
@@ -332,6 +415,14 @@
         <source>Choose...</source>
         <translation type="unfinished">Seç...</translation>
     </message>
+    <message>
+        <source>Copy quantity</source>
+        <translation>Miqdarı kopyalayın</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Dəyişikliyi kopyalayın</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(etiket yoxdur)</translation>
@@ -344,6 +435,21 @@
         <translation type="unfinished">&amp;Etiket:</translation>
     </message>
     </context>
+<context>
+    <name>ShutdownWindow</name>
+    </context>
+<context>
+    <name>SignVerifyMessageDialog</name>
+    </context>
+<context>
+    <name>TrafficGraphWidget</name>
+    </context>
+<context>
+    <name>TransactionDesc</name>
+    </context>
+<context>
+    <name>TransactionDescDialog</name>
+    </context>
 <context>
     <name>TransactionTableModel</name>
     <message>
@@ -357,6 +463,10 @@
     </context>
 <context>
     <name>TransactionView</name>
+    <message>
+        <source>Other</source>
+        <translation>Başqa</translation>
+    </message>
     <message>
         <source>&amp;Copy address</source>
         <translation>&amp;Ünvanı kopyala</translation>
@@ -382,6 +492,22 @@
         <translation>İxrac edilmədi</translation>
     </message>
     </context>
+<context>
+    <name>UnitDisplayStatusBarControl</name>
+    </context>
+<context>
+    <name>WalletController</name>
+    </context>
+<context>
+    <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Xəta</translation>
+    </message>
+    </context>
+<context>
+    <name>WalletModel</name>
+    </context>
 <context>
     <name>WalletView</name>
     <message>
@@ -392,10 +518,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Hazırki vərəqdəki verilənləri fayla ixrac edin</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Xəta</translation>
-    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
@@ -403,6 +525,14 @@
         <source>Error</source>
         <translation>Xəta</translation>
     </message>
+    <message>
+        <source>Replaying blocks...</source>
+        <translation>Bloklar yenidən səsləndirilir...</translation>
+    </message>
+    <message>
+        <source>The source code is available from %s.</source>
+        <translation>Mənbə kodu %s-dən əldə edilə bilər.</translation>
+    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Yetərsiz balans</translation>
