@@ -127,6 +127,10 @@
         <source>Repeat new passphrase</source>
         <translation>Паўтарыце новую кодавую фразу</translation>
     </message>
+    <message>
+        <source>Show passphrase</source>
+        <translation>Паказаць кодавую фразу</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Зашыфраваць гаманец.</translation>
@@ -273,10 +277,6 @@
         <source>&amp;Backup Wallet...</source>
         <translation>Стварыць копію гаманца...</translation>
     </message>
-    <message>
-        <source>&amp;Change Passphrase...</source>
-        <translation>&amp;Change Passphrase...</translation>
-    </message>
     <message>
         <source>Open &amp;URI...</source>
         <translation>Адчыниць &amp;URI...</translation>
@@ -691,7 +691,7 @@
         <source>Paste address from clipboard</source>
         <translation>Уставіць адрас з буферу абмена</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -957,18 +957,10 @@
         <source>&amp;Label:</source>
         <translation>Метка:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Уставіць адрас з буферу абмена</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Паведамленне:</translation>
@@ -987,17 +979,17 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Уставіць адрас з буферу абмена</translation>
     </message>
     <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
+        <source>&amp;Verify Message</source>
+        <translation>Праверыць паведамленне</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">Праверыць паведамленне</translation>
     </message>
     </context>
 <context>
@@ -1095,10 +1087,6 @@
         <source>Mined</source>
         <translation>Здабыта</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>непазначаны</translation>
@@ -1214,10 +1202,6 @@
         <source>Address</source>
         <translation>Адрас</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>Экспартаванне няўдалае</translation>
@@ -1239,6 +1223,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Памылка</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1257,10 +1245,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Экспартаваць гэтыя звесткі у файл</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Памылка</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Стварыць копію гаманца</translation>
