@@ -15,7 +15,7 @@
     </message>
     <message>
         <source>&amp;Copy</source>
-        <translation>&amp;Copy</translation>
+        <translation>Копирай</translation>
     </message>
     <message>
         <source>C&amp;lose</source>
@@ -83,7 +83,7 @@
     </message>
     <message>
         <source>Comma separated file (*.csv)</source>
-        <translation>Comma separated file (*.csv)</translation>
+        <translation>CSV файл (*.csv)</translation>
     </message>
     <message>
         <source>Exporting Failed</source>
@@ -727,6 +727,11 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>Създайте портфейл</translation>
+    </message>
     <message>
         <source>Create wallet failed</source>
         <translation>Създаването на портфейл не бе успешен</translation>
@@ -928,21 +933,22 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Вмъкни от клипборда</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
         <source>default wallet</source>
         <translation>Портфейл по подразбиране</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Отворете портфейл</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -1184,10 +1190,6 @@
     </context>
 <context>
     <name>PSBTOperationsDialog</name>
-    <message>
-        <source>Dialog</source>
-        <translation>Dialog</translation>
-    </message>
     <message>
         <source>Close</source>
         <translation type="unfinished">Затвори</translation>
@@ -1588,6 +1590,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Request payment to ...</source>
+        <translation type="unfinished">Изискване на плащане от ...</translation>
+    </message>
     <message>
         <source>Address:</source>
         <translation type="unfinished">Адрес:</translation>
@@ -1853,18 +1859,10 @@
         <source>Choose previously used address</source>
         <translation>Изберете използван преди адрес</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Вмъкни от клипборда</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Remove this entry</source>
         <translation>Премахване на този запис</translation>
@@ -1903,18 +1901,10 @@
         <source>Choose previously used address</source>
         <translation>Изберете използван преди адрес</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Вмъкни от клипборда</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Въведете съобщението тук</translation>
@@ -2125,15 +2115,7 @@
         <source>Amount</source>
         <translation>Количество</translation>
     </message>
-    <message>
-        <source>true</source>
-        <translation>true</translation>
-    </message>
-    <message>
-        <source>false</source>
-        <translation>false</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDescDialog</name>
     <message>
@@ -2207,10 +2189,6 @@
         <source>watch-only</source>
         <translation>само гледане</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(без етикет)</translation>
@@ -2312,7 +2290,7 @@
     </message>
     <message>
         <source>Comma separated file (*.csv)</source>
-        <translation>Comma separated file (*.csv)</translation>
+        <translation>CSV файл (*.csv)</translation>
     </message>
     <message>
         <source>Confirmed</source>
@@ -2383,7 +2361,11 @@
         <source>Create a new wallet</source>
         <translation>Създай нов портфейл</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>грешка</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -2405,10 +2387,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Изнеси данните в избрания раздел към файл</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>грешка</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Запазване на портфейла</translation>
