@@ -145,7 +145,11 @@
     </message>
     <message>
         <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
-        <translation>Za otključavanje novčanika za ovu operaciju potrebna je lozinka vašeg novčanika.</translation>
+        <translation>Ova radnja treba lozinku vašeg novčanika da dešifrira novčanik.</translation>
+    </message>
+    <message>
+        <source>Decrypt wallet</source>
+        <translation>Dešifrirati novčanik</translation>
     </message>
     <message>
         <source>Change passphrase</source>
@@ -215,6 +219,10 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation>Lozinka unesena za dešifriranje novčanika nije ispravna.</translation>
     </message>
+    <message>
+        <source>Wallet decryption failed</source>
+        <translation>Dešifriranje novčanika neuspješno</translation>
+    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation>Lozinka za novčanik uspješno je promijenjena.</translation>
@@ -257,6 +265,10 @@
         <source>Browse transaction history</source>
         <translation>Pregledajte historiju transakcija</translation>
     </message>
+    <message>
+        <source>E&amp;xit</source>
+        <translation>&amp;Izlaz</translation>
+    </message>
     <message>
         <source>Quit application</source>
         <translation>Zatvori aplikaciju</translation>
@@ -534,6 +546,16 @@
         <source>%1 client</source>
         <translation>%1 klijent</translation>
     </message>
+    <message>
+        <source>Click for more actions.</source>
+        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
+        <translation type="unfinished">Klikni za još radnji</translation>
+    </message>
+    <message>
+        <source>Disable network activity</source>
+        <extracomment>A context menu item.</extracomment>
+        <translation type="unfinished">Onemogući rad mreže</translation>
+    </message>
     <message>
         <source>Connecting to peers...</source>
         <translation>Povezivanje s vršnjacima...</translation>
@@ -605,6 +627,10 @@
         <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
         <translation>Privatni ključ je &lt;b&gt;onemogućen&lt;/b&gt;</translation>
     </message>
+    <message>
+        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
+        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno je &lt;b&gt;unzaključan&lt;/b&gt;</translation>
+    </message>
     <message>
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno je &lt;b&gt;zaključan&lt;/b&gt;</translation>
@@ -771,8 +797,14 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>Kreirajte Novčanik</translation>
+    </message>
     <message>
         <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
         <translation>Kreiranje novčanika &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
     <message>
@@ -1064,13 +1096,18 @@
         <source>Open bitcoin URI</source>
         <translation>Otvorite bitcoin URI</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
         <source>default wallet</source>
         <translation>zadani novčanik</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Otvorite Novčanik</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -1131,12 +1168,12 @@
         <translation>&amp;Mreža</translation>
     </message>
     <message>
-        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
-        <translation>Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova.</translation>
+        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
+        <translation>Onemogućuje neke napredne stavke ali svi blokovi će i dalje biti u potpunosti validni(provjereni). Opoziv ove postavke zahtijeva ponovno skidanje čitavog blockchaina. Stvarna iskorištenost diska može da bude nešto veća.</translation>
     </message>
     <message>
-        <source>MiB</source>
-        <translation>MiB</translation>
+        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
+        <translation>Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova.</translation>
     </message>
     <message>
         <source>(0 = auto, &lt;0 = leave that many cores free)</source>
@@ -1170,10 +1207,6 @@
         <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
         <translation>Povežite se s Bitcoin mrežom putem SOCKS5 proxyja.</translation>
     </message>
-    <message>
-        <source>Proxy &amp;IP:</source>
-        <translation>Proxy &amp;IP:</translation>
-    </message>
     <message>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Port proxyja (npr. 9050)</translation>
@@ -1182,18 +1215,6 @@
         <source>Used for reaching peers via:</source>
         <translation>Koristi se za dosezanje vršnjaka putem:</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Prozor</translation>
@@ -1214,6 +1235,10 @@
         <source>Error</source>
         <translation>Greška</translation>
     </message>
+    <message>
+        <source>The configuration file could not be opened.</source>
+        <translation>Konfiguracijski falj nije bilo moguce otvoriti.</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -1221,6 +1246,14 @@
         <source>Form</source>
         <translation>Obrazac</translation>
     </message>
+    <message>
+        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
+        <translation>Moguće je da su prikazane informacije zastarjele.Vaš novčanik se automatski sinhronizira sa Bitcoin mrežom nakon što je konekcija uspostavljena, ali proces nije još uvijek dovršen.</translation>
+    </message>
+    <message>
+        <source>Recent transactions</source>
+        <translation>Nedavne transakcije</translation>
+    </message>
     </context>
 <context>
     <name>PSBTOperationsDialog</name>
@@ -1458,14 +1491,6 @@
         <source>&amp;Label:</source>
         <translation type="unfinished">&amp;Oznaka:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     </context>
 <context>
     <name>ShutdownWindow</name>
@@ -1481,12 +1506,12 @@
 <context>
     <name>SignVerifyMessageDialog</name>
     <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Potvrdi poruku</translation>
     </message>
     <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Potvrdi poruku</translation>
     </message>
     </context>
 <context>
@@ -1616,7 +1641,11 @@
         <source>Create a new wallet</source>
         <translation>Kreirajte novi novčanik</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>Greška</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1634,10 +1663,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Izvezite podatke trenutne kartice u datoteku</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Greška</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Rezervni Novčanik</translation>
@@ -1645,9 +1670,189 @@
     </context>
 <context>
     <name>bitcoin-core</name>
+    <message>
+        <source>Unable to start HTTP server. See debug log for details.</source>
+        <translation>Nije moguće pokrenuti HTTP server. Pogledajte dnevnik otklanjanja grešaka za detalje.</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Greška</translation>
     </message>
+    <message>
+        <source>SQLiteDatabase: Failed to execute statement to verify database: %s</source>
+        <translation>SQLiteDatabase: Izvršenje naredbe za provjeru baze podataka nije uspjelo: %s</translation>
+    </message>
+    <message>
+        <source>SQLiteDatabase: Failed to prepare statement to verify database: %s</source>
+        <translation>SQLiteDatabase: Nije uspjela priprema naredbe za provjeru baze podataka: %s</translation>
+    </message>
+    <message>
+        <source>SQLiteDatabase: Failed to read database verification error: %s</source>
+        <translation>SQLiteDatabase: Neuspjelo čitanje greške verifikacije baze podataka: %s</translation>
+    </message>
+    <message>
+        <source>SQLiteDatabase: Unexpected application id. Expected %u, got %u</source>
+        <translation>SQLiteDatabase: Neočekivani ID aplikacije. Ocekivao %u, dobio %u</translation>
+    </message>
+    <message>
+        <source>Specified blocks directory "%s" does not exist.</source>
+        <translation>Navedeni direktorij blokova "%s" ne postoji.</translation>
+    </message>
+    <message>
+        <source>The specified R/W config file %s does not exist
+</source>
+        <translation>Navedena R/W konfiguracijska datoteka %s ne postoji
+</translation>
+    </message>
+    <message>
+        <source>Unable to open %s for writing</source>
+        <translation type="unfinished">Nije moguće otvoriti %s za pisanje</translation>
+    </message>
+    <message>
+        <source>Unknown address type '%s'</source>
+        <translation>Nepoznata vrsta adrese '%s'</translation>
+    </message>
+    <message>
+        <source>Unknown change type '%s'</source>
+        <translation>Nepoznata vrsta promjene '%s'</translation>
+    </message>
+    <message>
+        <source>Upgrading txindex database</source>
+        <translation>Nadogradnja txindex baze podataka</translation>
+    </message>
+    <message>
+        <source>Replaying blocks...</source>
+        <translation type="unfinished">Reprodukcija blokova...</translation>
+    </message>
+    <message>
+        <source>The source code is available from %s.</source>
+        <translation>Izvorni kod je dostupan od %s.</translation>
+    </message>
+    <message>
+        <source>Unable to bind to %s on this computer. %s is probably already running.</source>
+        <translation>Nije moguće povezati se na %s na ovom računaru. %s vjerovatno već radi.</translation>
+    </message>
+    <message>
+        <source>Unable to generate keys</source>
+        <translation type="unfinished">Nije moguće generirati ključeve</translation>
+    </message>
+    <message>
+        <source>Unsupported logging category %s=%s.</source>
+        <translation>Nepodržana kategorija logivanja %s=%s.</translation>
+    </message>
+    <message>
+        <source>Upgrading UTXO database</source>
+        <translation>Nadogradnja UTXO baze podataka</translation>
+    </message>
+    <message>
+        <source>User Agent comment (%s) contains unsafe characters.</source>
+        <translation>Komentar korisničkog agenta (%s) sadrži nesigurne znakove.</translation>
+    </message>
+    <message>
+        <source>Verifying blocks...</source>
+        <translation type="unfinished">Provjera blokova...</translation>
+    </message>
+    <message>
+        <source>Wallet needed to be rewritten: restart %s to complete</source>
+        <translation>Novčanik je trebao biti prepisan: ponovo pokrenite %s da biste završili</translation>
+    </message>
+    <message>
+        <source>Section [%s] is not recognized.</source>
+        <translation>Odjeljak [%s] nije prepoznat.</translation>
+    </message>
+    <message>
+        <source>Signing transaction failed</source>
+        <translation>Potpisivanje transakcije nije uspjelo</translation>
+    </message>
+    <message>
+        <source>Specified -walletdir "%s" does not exist</source>
+        <translation>Navedeni -walletdir "%s" ne postoji</translation>
+    </message>
+    <message>
+        <source>Specified -walletdir "%s" is a relative path</source>
+        <translation>Navedeni -walletdir "%s" je relativna putanja</translation>
+    </message>
+    <message>
+        <source>Specified -walletdir "%s" is not a directory</source>
+        <translation>Navedeni -walletdir "%s" nije direktorij</translation>
+    </message>
+    <message>
+        <source>The specified config file %s does not exist
+</source>
+        <translation type="unfinished">Navedena konfiguracijska datoteka %s ne postoji
+</translation>
+    </message>
+    <message>
+        <source>The transaction amount is too small to pay the fee</source>
+        <translation>Iznos transakcije je premali za plaćanje naknade</translation>
+    </message>
+    <message>
+        <source>This is experimental software.</source>
+        <translation>Ovo je eksperimentalni softver.</translation>
+    </message>
+    <message>
+        <source>Transaction amount too small</source>
+        <translation>Iznos transakcije je premali</translation>
+    </message>
+    <message>
+        <source>Transaction too large</source>
+        <translation>Transakcija je prevelika</translation>
+    </message>
+    <message>
+        <source>Unable to bind to %s on this computer (bind returned error %s)</source>
+        <translation>Nije moguće povezati se na %s na ovom računaru (povezivanje je vratilo grešku %s)</translation>
+    </message>
+    <message>
+        <source>Unable to create the PID file '%s': %s</source>
+        <translation>Nije moguće kreirati PID fajl '%s': %s</translation>
+    </message>
+    <message>
+        <source>Unable to generate initial keys</source>
+        <translation>Nije moguće generirati početne ključeve</translation>
+    </message>
+    <message>
+        <source>Unknown -blockfilterindex value %s.</source>
+        <translation>Nepoznata vrijednost -blockfilterindex %s.</translation>
+    </message>
+    <message>
+        <source>Verifying wallet(s)...</source>
+        <translation type="unfinished">Provjera novčanika...</translation>
+    </message>
+    <message>
+        <source>Starting network threads...</source>
+        <translation type="unfinished">Pokretanje mrežnih niti...</translation>
+    </message>
+    <message>
+        <source>The wallet will avoid paying less than the minimum relay fee.</source>
+        <translation>Novčanik će izbjeći plaćanje manje od minimalne relejne naknade.</translation>
+    </message>
+    <message>
+        <source>This is the minimum transaction fee you pay on every transaction.</source>
+        <translation>Ovo je minimalna naknada za transakciju koju plaćate za svaku transakciju.</translation>
+    </message>
+    <message>
+        <source>This is the transaction fee you will pay if you send a transaction.</source>
+        <translation>Ovo je naknada za transakciju koju ćete platiti ako pošaljete transakciju.</translation>
+    </message>
+    <message>
+        <source>Transaction amounts must not be negative</source>
+        <translation>Iznosi transakcija ne smiju biti negativni</translation>
+    </message>
+    <message>
+        <source>Transaction has too long of a mempool chain</source>
+        <translation>Transakcija ima predugačak mempool lanac </translation>
+    </message>
+    <message>
+        <source>Transaction must have at least one recipient</source>
+        <translation>Transakcija mora imati najmanje jednog primaoca</translation>
+    </message>
+    <message>
+        <source>Unknown network specified in -onlynet: '%s'</source>
+        <translation>Nepoznata mreža navedena u -onlynet: '%s'</translation>
+    </message>
+    <message>
+        <source>Rescanning...</source>
+        <translation type="unfinished">Ponovno skeniranje...</translation>
+    </message>
     </context>
-</TS>
\ No newline at end of file
+</TS>
