@@ -92,10 +92,6 @@
 </context>
 <context>
     <name>AddressTableModel</name>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Address</source>
         <translation>Cyfeiriad</translation>
@@ -492,12 +488,6 @@
         <source>Type: %1
 </source>
         <translation>Math: %1
-</translation>
-    </message>
-    <message>
-        <source>Label: %1
-</source>
-        <translation>Label: %1
 </translation>
     </message>
     <message>
@@ -638,10 +628,6 @@
         <source>Edit Address</source>
         <translation>Golygu'r cyfeiriad</translation>
     </message>
-    <message>
-        <source>&amp;Label</source>
-        <translation>&amp;Label</translation>
-    </message>
     <message>
         <source>&amp;Address</source>
         <translation>&amp;Cyfeiriad</translation>
@@ -691,10 +677,6 @@
         <source>Welcome</source>
         <translation>Croeso</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Gwall</translation>
@@ -722,17 +704,18 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Agor Waled</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -748,18 +731,6 @@
         <source>W&amp;allet</source>
         <translation>W&amp;aled</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Ffenestr</translation>
@@ -877,10 +848,6 @@
         <source>&amp;Amount:</source>
         <translation>&amp;Maint</translation>
     </message>
-    <message>
-        <source>&amp;Label:</source>
-        <translation>&amp;Label:</translation>
-    </message>
     <message>
         <source>&amp;Message:</source>
         <translation>&amp;Neges:</translation>
@@ -931,10 +898,6 @@
         <source>Date</source>
         <translation>Dyddiad</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Message</source>
         <translation>Neges</translation>
@@ -1021,22 +984,10 @@
         <source>A&amp;mount:</source>
         <translation>&amp;Maint</translation>
     </message>
-    <message>
-        <source>&amp;Label:</source>
-        <translation>&amp;Label:</translation>
-    </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Neges:</translation>
@@ -1047,17 +998,17 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
     </message>
     <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Gwirio neges</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Gwirio neges</translation>
     </message>
     </context>
 <context>
@@ -1099,10 +1050,6 @@
         <source>Type</source>
         <translation>Math</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Open until %1</source>
         <translation>Agor tan %1</translation>
@@ -1162,10 +1109,6 @@
         <source>Type</source>
         <translation>Math</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Address</source>
         <translation>Cyfeiriad</translation>
@@ -1187,6 +1130,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Gwall</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1217,10 +1164,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Allforio'r data yn y tab presennol i ffeil</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Gwall</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Backup Waled</translation>
