@@ -712,6 +712,11 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>Krei Monujon</translation>
+    </message>
     <message>
         <source>Create wallet failed</source>
         <translation>Krei monujon malsukcesis</translation>
@@ -949,15 +954,11 @@
         <source>Open bitcoin URI</source>
         <translation>Malfermi na la URI de bitmono</translation>
     </message>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Alglui adreson de tondejo</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -972,8 +973,14 @@
         <source>default wallet</source>
         <translation>defaŭlta monujo</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Malfermi la Monujon</translation>
+    </message>
     <message>
         <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
         <translation>Malfermadas Monujon &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
 </context>
@@ -1055,14 +1062,6 @@
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>la pordo de la prokurilo (ekz. 9050)</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Fenestro</translation>
@@ -1246,14 +1245,6 @@
         <source>Amount</source>
         <translation>Sumo</translation>
     </message>
-    <message>
-        <source>%1 h</source>
-        <translation>%1 h</translation>
-    </message>
-    <message>
-        <source>%1 m</source>
-        <translation>%1 m</translation>
-    </message>
     <message>
         <source>None</source>
         <translation>Neniu</translation>
@@ -1290,22 +1281,6 @@
         <source>%n year(s)</source>
         <translation><numerusform>%n jaro</numerusform><numerusform>%n jaroj</numerusform></translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>Error: Specified data directory "%1" does not exist.</source>
         <translation>Eraro: la elektita dosierujo por datumoj "%1" ne ekzistas.</translation>
@@ -1556,6 +1531,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Request payment to ...</source>
+        <translation type="unfinished">Peti pagon al ...</translation>
+    </message>
     <message>
         <source>Address:</source>
         <translation>Adreso:</translation>
@@ -1805,18 +1784,10 @@
         <source>Choose previously used address</source>
         <translation>Elektu la jam uzitan adreson</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Alglui adreson de tondejo</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Remove this entry</source>
         <translation>Forigu ĉi tiun enskribon</translation>
@@ -1859,18 +1830,10 @@
         <source>Choose previously used address</source>
         <translation>Elektu la jam uzitan adreson</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Alglui adreson de tondejo</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Tajpu la mesaĝon, kiun vi volas sendi, cîi tie</translation>
@@ -1970,11 +1933,7 @@
 </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -2270,10 +2229,6 @@
         <source>Address</source>
         <translation>Adreso</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>ekspotado malsukcesinta</translation>
@@ -2307,7 +2262,11 @@
         <source>Create a new wallet</source>
         <translation>Krei novan monujon</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>Eraro</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -2329,10 +2288,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Eksporti la datumojn el la aktuala langeto al dosiero</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Eraro</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Krei sekurkopion de monujo</translation>
