@@ -383,10 +383,6 @@
         <source>Transactions after this will not yet be visible.</source>
         <translation>Transacciones después de esta no serán visibles todavía.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Advertencia</translation>
@@ -450,10 +446,6 @@
         <source>Quantity:</source>
         <translation>Cantidad:</translation>
     </message>
-    <message>
-        <source>Bytes:</source>
-        <translation>Bytes:</translation>
-    </message>
     <message>
         <source>Amount:</source>
         <translation>Monto:</translation>
@@ -566,10 +558,6 @@
         <source>yes</source>
         <translation>si</translation>
     </message>
-    <message>
-        <source>no</source>
-        <translation>no</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(sin etiqueta)</translation>
@@ -700,10 +688,6 @@
         <source>Use a custom data directory:</source>
         <translation>Usa un directorio de datos personalizado:</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
         <translation>Se almacenará al menos %1GB de datos en este directorio, que irá creciendo con el tiempo.</translation>
@@ -720,10 +704,6 @@
         <source>Error: Specified data directory "%1" cannot be created.</source>
         <translation>Error: Directorio de datos especificado "%1" no puede ser creado.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     </context>
 <context>
     <name>MempoolStats</name>
@@ -762,15 +742,11 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -782,7 +758,7 @@
     </message>
     <message>
         <source>&amp;Main</source>
-        <translation>&amp;Main</translation>
+        <translation>&amp;Principal</translation>
     </message>
     <message>
         <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
@@ -892,10 +868,6 @@
         <source>Client restart required to activate changes.</source>
         <translation>Reinicio del cliente para activar cambios.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>This change would require a client restart.</source>
         <translation>Este cambio requiere reinicio por parte del cliente.</translation>
@@ -939,10 +911,6 @@
         <source>Mined balance that has not yet matured</source>
         <translation>Saldo recién minado que aún no está disponible.</translation>
     </message>
-    <message>
-        <source>Total:</source>
-        <translation>Total:</translation>
-    </message>
     <message>
         <source>Your current total balance</source>
         <translation>Su balance actual total</translation>
@@ -991,14 +959,6 @@
         <source>Amount</source>
         <translation>Monto</translation>
     </message>
-    <message>
-        <source>%1 h</source>
-        <translation>%1 h</translation>
-    </message>
-    <message>
-        <source>%1 m</source>
-        <translation>%1 m</translation>
-    </message>
     <message>
         <source>N/A</source>
         <translation>N/D</translation>
@@ -1007,22 +967,6 @@
         <source>%1 and %2</source>
         <translation>%1 y %2</translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>Error: Specified data directory "%1" does not exist.</source>
         <translation>Error: El directorio de datos especificado "%1" no existe.</translation>
@@ -1083,10 +1027,6 @@
         <source>&amp;Information</source>
         <translation>Información</translation>
     </message>
-    <message>
-        <source>General</source>
-        <translation>General</translation>
-    </message>
     <message>
         <source>Startup time</source>
         <translation>Hora de inicio</translation>
@@ -1226,6 +1166,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Request payment to ...</source>
+        <translation type="unfinished">Solicitar pago a ...</translation>
+    </message>
     <message>
         <source>Address:</source>
         <translation type="unfinished">Dirección:</translation>
@@ -1316,10 +1260,6 @@
         <source>Quantity:</source>
         <translation>Cantidad:</translation>
     </message>
-    <message>
-        <source>Bytes:</source>
-        <translation>Bytes:</translation>
-    </message>
     <message>
         <source>Amount:</source>
         <translation>Monto:</translation>
@@ -1479,18 +1419,10 @@
         <source>Choose previously used address</source>
         <translation>Escoger dirección previamente usada</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Remove this entry</source>
         <translation>Eliminar esta transacción</translation>
@@ -1507,11 +1439,7 @@
         <source>Pay To:</source>
         <translation>Paga a:</translation>
     </message>
-    <message>
-        <source>Memo:</source>
-        <translation>Memo:</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>ShutdownWindow</name>
     </context>
@@ -1529,18 +1457,10 @@
         <source>Choose previously used address</source>
         <translation>Escoger dirección previamente usada</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Introduzca el mensaje que desea firmar aquí</translation>
@@ -1640,11 +1560,7 @@
 </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -1940,10 +1856,6 @@
         <source>Address</source>
         <translation>Direccion</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>Error al exportar</translation>
@@ -1995,10 +1907,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Exportar los datos en la pestaña actual a un archivo</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Respaldo de monedero</translation>
