@@ -406,10 +406,6 @@
         <source>Transactions after this will not yet be visible.</source>
         <translation>Las transacciones posteriores aún no están visibles.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Aviso</translation>
@@ -477,10 +473,6 @@
         <source>Quantity:</source>
         <translation>Cantidad:</translation>
     </message>
-    <message>
-        <source>Bytes:</source>
-        <translation>Bytes:</translation>
-    </message>
     <message>
         <source>Amount:</source>
         <translation>Cuantía:</translation>
@@ -593,10 +585,6 @@
         <source>yes</source>
         <translation>si</translation>
     </message>
-    <message>
-        <source>no</source>
-        <translation>no</translation>
-    </message>
     <message>
         <source>Can vary +/- %1 satoshi(s) per input.</source>
         <translation>Puede variar +/- %1 satoshi(s) por entrada.</translation>
@@ -616,6 +604,11 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation type="unfinished">Crear Billetera</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
@@ -731,10 +724,6 @@
         <source>Use a custom data directory:</source>
         <translation>Utilice un directorio de datos personalizado:</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
         <translation>Al menos %1GB de datos serán almacenados en este directorio, y crecerá con el tiempo.</translation>
@@ -751,10 +740,6 @@
         <source>Error: Specified data directory "%1" cannot be created.</source>
         <translation>Error: Directorio de datos especificado "%1" no puede ser creado.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     </context>
 <context>
     <name>MempoolStats</name>
@@ -784,15 +769,11 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -918,10 +899,6 @@
         <source>Client restart required to activate changes.</source>
         <translation>Reinicio del cliente para activar cambios.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>This change would require a client restart.</source>
         <translation>Este cambio requiere reinicio por parte del cliente.</translation>
@@ -965,10 +942,6 @@
         <source>Mined balance that has not yet matured</source>
         <translation>Saldo recién minado que aún no está disponible.</translation>
     </message>
-    <message>
-        <source>Total:</source>
-        <translation>Total:</translation>
-    </message>
     <message>
         <source>Your current total balance</source>
         <translation>Su balance actual total</translation>
@@ -996,14 +969,6 @@
         <source>Amount</source>
         <translation>Cantidad</translation>
     </message>
-    <message>
-        <source>%1 h</source>
-        <translation>%1 h</translation>
-    </message>
-    <message>
-        <source>%1 m</source>
-        <translation>%1 m</translation>
-    </message>
     <message>
         <source>N/A</source>
         <translation>N/D</translation>
@@ -1012,22 +977,6 @@
         <source>%1 and %2</source>
         <translation>%1 y %2</translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation>desconocido</translation>
@@ -1064,10 +1013,6 @@
         <source>&amp;Information</source>
         <translation>Información</translation>
     </message>
-    <message>
-        <source>General</source>
-        <translation>General</translation>
-    </message>
     <message>
         <source>Startup time</source>
         <translation>Hora de inicio</translation>
@@ -1281,10 +1226,6 @@
         <source>Quantity:</source>
         <translation>Cantidad:</translation>
     </message>
-    <message>
-        <source>Bytes:</source>
-        <translation>Bytes:</translation>
-    </message>
     <message>
         <source>Amount:</source>
         <translation>Cuantía:</translation>
@@ -1404,18 +1345,10 @@
         <source>Choose previously used address</source>
         <translation>Escoger dirección previamente usada</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Remove this entry</source>
         <translation>Eliminar esta transacción</translation>
@@ -1432,11 +1365,7 @@
         <source>Pay To:</source>
         <translation>Paga a:</translation>
     </message>
-    <message>
-        <source>Memo:</source>
-        <translation>Memo:</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>ShutdownWindow</name>
     </context>
@@ -1454,18 +1383,10 @@
         <source>Choose previously used address</source>
         <translation>Escoger dirección previamente usada</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Pegar dirección desde portapapeles</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Introduzca el mensaje que desea firmar aquí</translation>
@@ -1513,11 +1434,7 @@
     </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -1630,7 +1547,7 @@
         <source>Create a new wallet</source>
         <translation>Crear una nueva billetera</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1652,10 +1569,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Exportar a un archivo los datos de esta pestaña</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Billetera de Respaldo</translation>
