@@ -729,10 +729,6 @@
         <source>Welcome</source>
         <translation>Tere tulemast</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Viga</translation>
@@ -772,15 +768,11 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Kleebi aadress vahemälust</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -830,26 +822,10 @@
         <source>Proxy &amp;IP:</source>
         <translation>Proxi &amp;IP:</translation>
     </message>
-    <message>
-        <source>&amp;Port:</source>
-        <translation>&amp;Port:</translation>
-    </message>
     <message>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Proxi port (nt 9050)</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Aken</translation>
@@ -882,10 +858,6 @@
         <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
         <translation>Vali liideses ning müntide saatmisel kuvatav vaikimisi alajaotus.</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
-    </message>
     <message>
         <source>&amp;Cancel</source>
         <translation>&amp;Katkesta</translation>
@@ -1001,14 +973,6 @@
         <source>Inbound</source>
         <translation>Sisenev</translation>
     </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
-    <message>
-        <source>%1 ms</source>
-        <translation>%1 ms</translation>
-    </message>
     <message numerus="yes">
         <source>%n hour(s)</source>
         <translation><numerusform>%n tund</numerusform><numerusform>%n tundi</numerusform></translation>
@@ -1029,22 +993,10 @@
         <source>%n year(s)</source>
         <translation><numerusform>%n aasta</numerusform><numerusform>%n aastat</numerusform></translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
     <message>
         <source>%1 KB</source>
         <translation>%1 B</translation>
     </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>Error: %1</source>
         <translation>Tõrge %1</translation>
@@ -1089,10 +1041,6 @@
     </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>Client version</source>
         <translation>Kliendi versioon</translation>
@@ -1505,18 +1453,10 @@
         <source>Choose previously used address</source>
         <translation>Vali eelnevalt kasutatud aadress</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Kleebi aadress vahemälust</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>S&amp;ubtract fee from amount</source>
         <translation>L&amp;ahuta tehingutasu summast</translation>
@@ -1559,18 +1499,10 @@
         <source>Choose previously used address</source>
         <translation>Vali eelnevalt kasutatud aadress</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Kleebi aadress vahemälust</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Sisesta siia allkirjastamise sõnum</translation>
@@ -1674,11 +1606,7 @@
 </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -1847,10 +1775,6 @@
         <source>Mined</source>
         <translation>Mine'itud</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(silt puudub)</translation>
@@ -1970,10 +1894,6 @@
         <source>Address</source>
         <translation>Aadress</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>Eksport ebaõnnestus.</translation>
@@ -1999,7 +1919,11 @@
         <source>Create a new wallet</source>
         <translation>Loo uus rahakott</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>Viga</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -2017,10 +1941,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Ekspordi kuvatava vahelehe sisu faili</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Viga</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Varunda Rahakott</translation>
@@ -2137,4 +2057,4 @@
         <translation>Laetud</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
