@@ -735,8 +735,14 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>Diruzorroa sortu</translation>
+    </message>
     <message>
         <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
         <translation>Diruzorroa sortzen&lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
     <message>
@@ -850,10 +856,6 @@
         <source>Welcome to %1.</source>
         <translation>Ongietorri %1-ra</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Akatsa</translation>
@@ -917,7 +919,7 @@
         <source>Paste address from clipboard</source>
         <translation>Arbeletik helbidea itsatsi</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -932,8 +934,14 @@
         <source>default wallet</source>
         <translation>Diruzorro lehenetsia</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Diruzorroa zabaldu</translation>
+    </message>
     <message>
         <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
         <translation>Diru-zorroa irekitzen &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
 </context>
@@ -1011,10 +1019,6 @@
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Proxy portua (9050 adibidez)</translation>
     </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Lehioa</translation>
@@ -1110,9 +1114,6 @@
         <translation>Itxi</translation>
     </message>
     </context>
-<context>
-    <name>PairingPage</name>
-    </context>
 <context>
     <name>PaymentServer</name>
     <message>
@@ -1391,18 +1392,10 @@
         <source>&amp;Label:</source>
         <translation>&amp;Etiketa:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Arbeletik helbidea itsatsi</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Mezua:</translation>
@@ -1417,17 +1410,17 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Arbeletik helbidea itsatsi</translation>
     </message>
     <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
+        <source>&amp;Verify Message</source>
+        <translation>Mezua &amp;balioztatu</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">Mezua &amp;balioztatu</translation>
     </message>
     <message>
         <source>No error</source>
@@ -1593,10 +1586,6 @@
         <source>watch-only</source>
         <translation>ikusi bakarrik</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(izendapenik ez)</translation>
@@ -1741,7 +1730,11 @@
         <source>Create a new wallet</source>
         <translation>Diruzorro berri bat sortu</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>Akatsa</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1763,10 +1756,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Uneko fitxategian datuak esportatu</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Akatsa</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished">Ezeztatu</translation>
