@@ -25,6 +25,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Eyða völdu færslugildi úr listanum</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Veldu veski eða merkingu fyrir leit</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Flytja gögn í flipanum í skrá</translation>
@@ -644,6 +648,9 @@
 <context>
     <name>FreespaceChecker</name>
     </context>
+<context>
+    <name>GuiNetWatch</name>
+    </context>
 <context>
     <name>HelpMessageDialog</name>
     <message>
@@ -657,10 +664,6 @@
 </context>
 <context>
     <name>Intro</name>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Villa</translation>
@@ -935,6 +938,14 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Yfirfara skilaboð</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Yfirfara skilaboð</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -1011,6 +1022,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Villa</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1025,10 +1040,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Flytja gögn í flipanum í skrá</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Villa</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Öryggisafrit á veski</translation>
