@@ -208,7 +208,7 @@
     </message>
     <message>
         <source>Copy amount</source>
-        <translation>Copy amount</translation>
+        <translation type="unfinished">Copy amount</translation>
     </message>
     <message>
         <source>&amp;Copy address</source>
@@ -226,30 +226,6 @@
         <source>Copy transaction &amp;ID</source>
         <translation type="unfinished">&amp;Copy transaction ID</translation>
     </message>
-    <message>
-        <source>Copy quantity</source>
-        <translation>Copy quantity</translation>
-    </message>
-    <message>
-        <source>Copy fee</source>
-        <translation>Copy fee</translation>
-    </message>
-    <message>
-        <source>Copy after fee</source>
-        <translation>Copy after fee</translation>
-    </message>
-    <message>
-        <source>Copy bytes</source>
-        <translation>Copy bytes</translation>
-    </message>
-    <message>
-        <source>Copy dust</source>
-        <translation>Copy dust</translation>
-    </message>
-    <message>
-        <source>Copy change</source>
-        <translation>Copy change</translation>
-    </message>
     <message>
         <source>yes</source>
         <translation>بەڵێ</translation>
@@ -417,10 +393,6 @@
 </context>
 <context>
     <name>PSBTOperationsDialog</name>
-    <message>
-        <source>Copy to Clipboard</source>
-        <translation>Copy to Clipboard</translation>
-    </message>
     <message>
         <source>Close</source>
         <translation type="unfinished">Cداخستن</translation>
@@ -454,17 +426,9 @@
         <source>Amount</source>
         <translation>سەرجەم</translation>
     </message>
-    <message>
-        <source>Error initializing settings: %1</source>
-        <translation>هەڵە لە دەستپێکردنی ڕێکخستنەکان: %1</translation>
-    </message>
     </context>
 <context>
     <name>QRImageWidget</name>
-    <message>
-        <source>&amp;Copy Image</source>
-        <translation>&amp;Copy Image</translation>
-    </message>
     <message>
         <source>Resulting URI too long, try to reduce the text for label / message.</source>
         <translation>ئەنجامی URL زۆر درێژە، هەوڵ بدە دەقەکە کەم بکەیتەوە بۆ پێناسە / نامە.</translation>
@@ -576,10 +540,6 @@
         <source>Remove</source>
         <translation>سڕینەوە</translation>
     </message>
-    <message>
-        <source>Copy &amp;URI</source>
-        <translation>Copy &amp;URI</translation>
-    </message>
     <message>
         <source>&amp;Copy address</source>
         <translation type="unfinished">&amp;ڕوونووسکردن ناوونیشان</translation>
@@ -615,13 +575,9 @@
         <source>Message:</source>
         <translation>پەیام:</translation>
     </message>
-    <message>
-        <source>Copy &amp;URI</source>
-        <translation>Copy &amp;URI</translation>
-    </message>
     <message>
         <source>Copy &amp;Address</source>
-        <translation>Copy &amp;Address</translation>
+        <translation>&amp;ڕوونووسکردن ناوونیشان</translation>
     </message>
     </context>
 <context>
@@ -671,33 +627,9 @@
         <source>S&amp;end</source>
         <translation type="unfinished">&amp;ناردن</translation>
     </message>
-    <message>
-        <source>Copy quantity</source>
-        <translation>Copy quantity</translation>
-    </message>
     <message>
         <source>Copy amount</source>
-        <translation>Copy amount</translation>
-    </message>
-    <message>
-        <source>Copy fee</source>
-        <translation>Copy fee</translation>
-    </message>
-    <message>
-        <source>Copy after fee</source>
-        <translation>Copy after fee</translation>
-    </message>
-    <message>
-        <source>Copy bytes</source>
-        <translation>Copy bytes</translation>
-    </message>
-    <message>
-        <source>Copy dust</source>
-        <translation>Copy dust</translation>
-    </message>
-    <message>
-        <source>Copy change</source>
-        <translation>Copy change</translation>
+        <translation type="unfinished">Copy amount</translation>
     </message>
     <message>
         <source>or</source>
@@ -750,10 +682,6 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Copy the current signature to the system clipboard</source>
-        <translation>Copy the current signature to the system clipboard</translation>
-    </message>
     <message>
         <source>Enter the receiver's address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack. Note that this only proves the signing party receives with the address, it cannot prove sendership of any transaction!</source>
         <translation>ناونیشانی وەرگرەکە بنووسە، نامە (دڵنیابە لەوەی کە جیاکەرەوەکانی هێڵ، مەوداکان، تابەکان، و هتد بە تەواوی کۆپی بکە) و لە خوارەوە واژووی بکە بۆ سەلماندنی نامەکە. وریابە لەوەی کە زیاتر نەیخوێنیتەوە بۆ ناو واژووەکە لەوەی کە لە خودی پەیامە واژووەکەدایە، بۆ ئەوەی خۆت بەدوور بگریت لە فێڵکردن لە هێرشی پیاوان لە ناوەنددا. سەرنج بدە کە ئەمە تەنیا لایەنی واژووکردن بە ناونیشانەکە وەربگرە، ناتوانێت نێرەری هیچ مامەڵەیەک بسەلمێنێت!</translation>
@@ -916,6 +844,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>هەڵە</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -930,10 +862,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>ناردنی داتا لە خشتەبەندی ئێستا بۆ فایلێک</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>هەڵە</translation>
-    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
