@@ -5,10 +5,22 @@
         <source>Create a new address</source>
         <translation>Crea novam inscriptionem</translation>
     </message>
+    <message>
+        <source>&amp;New</source>
+        <translation>&amp;Novus</translation>
+    </message>
     <message>
         <source>Copy the currently selected address to the system clipboard</source>
         <translation>Copia inscriptionem iam selectam in latibulum systematis</translation>
     </message>
+    <message>
+        <source>&amp;Copy</source>
+        <translation>&amp;Transcribe</translation>
+    </message>
+    <message>
+        <source>C&amp;lose</source>
+        <translation>C&amp;laude</translation>
+    </message>
     <message>
         <source>Delete the currently selected address from the list</source>
         <translation>Dele active selectam inscriptionem ex enumeratione</translation>
@@ -45,6 +57,10 @@
         <source>&amp;Edit</source>
         <translation>&amp;Muta</translation>
     </message>
+    <message>
+        <source>Export Address List</source>
+        <translation>Exporta Index Inscriptionum</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>Comma Separata Plica (*.csv)</translation>
@@ -83,6 +99,10 @@
         <source>Repeat new passphrase</source>
         <translation>Itera novam tesseram</translation>
     </message>
+    <message>
+        <source>Show passphrase</source>
+        <translation>Ostende tesseram</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Cifra cassidile</translation>
@@ -162,7 +182,11 @@
 </context>
 <context>
     <name>BanTableModel</name>
-    </context>
+    <message>
+        <source>Banned Until</source>
+        <translation>Interdictum usque ad</translation>
+    </message>
+</context>
 <context>
     <name>BitcoinGUI</name>
     <message>
@@ -197,6 +221,10 @@
         <source>Quit application</source>
         <translation>Exi applicatione</translation>
     </message>
+    <message>
+        <source>&amp;About %1</source>
+        <translation>&amp;De %1</translation>
+    </message>
     <message>
         <source>Show information about %1</source>
         <translation>Monstra informationem de %1</translation>
@@ -225,6 +253,18 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Muta tesseram...</translation>
     </message>
+    <message>
+        <source>Open &amp;URI...</source>
+        <translation>Aperi &amp;URI...</translation>
+    </message>
+    <message>
+        <source>Create Wallet...</source>
+        <translation>Creare Cassidilium</translation>
+    </message>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>Creare novum cassidilium</translation>
+    </message>
     <message>
         <source>Wallet:</source>
         <translation type="unfinished">Cassidile:</translation>
@@ -313,10 +353,6 @@
         <source>Transactions after this will not yet be visible.</source>
         <translation>Transactiones post hoc nondum visibiles erunt.</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Monitio</translation>
@@ -364,6 +400,10 @@
 </context>
 <context>
     <name>CoinControlDialog</name>
+    <message>
+        <source>Bytes:</source>
+        <translation>Octecti:</translation>
+    </message>
     <message>
         <source>Amount:</source>
         <translation>Quantitas:</translation>
@@ -467,6 +507,10 @@
         <source>version</source>
         <translation>versio</translation>
     </message>
+    <message>
+        <source>About %1</source>
+        <translation type="unfinished">De %1</translation>
+    </message>
     <message>
         <source>Command-line options</source>
         <translation>Optiones mandati initiantis</translation>
@@ -474,14 +518,9 @@
 </context>
 <context>
     <name>Intro</name>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
+    </context>
+<context>
+    <name>MempoolStats</name>
     </context>
 <context>
     <name>ModalOverlay</name>
@@ -517,7 +556,7 @@
         <source>Paste address from clipboard</source>
         <translation>Glutina inscriptionem ex latibulo</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -599,10 +638,6 @@
         <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
         <translation>Selige praedefinitam unitam subdivisionis monstrare in interfacie et quando nummos mittere</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
-    </message>
     <message>
         <source>&amp;Cancel</source>
         <translation>&amp;Cancella</translation>
@@ -619,10 +654,6 @@
         <source>Confirm options reset</source>
         <translation>Confirma optionum reconstituere</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>The supplied proxy address is invalid.</source>
         <translation>Inscriptio vicarii tradita non valida est.</translation>
@@ -649,6 +680,13 @@
     </context>
 <context>
     <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished">Claude</translation>
+    </message>
+    </context>
+<context>
+    <name>PairingPage</name>
     </context>
 <context>
     <name>PaymentServer</name>
@@ -674,10 +712,6 @@
         <source>Amount</source>
         <translation>Quantitas</translation>
     </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation>ignotum</translation>
@@ -710,10 +744,6 @@
     </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>Client version</source>
         <translation>Versio clientis</translation>
@@ -871,6 +901,10 @@
         <source>Insufficient funds!</source>
         <translation>Inopia nummorum</translation>
     </message>
+    <message>
+        <source>Bytes:</source>
+        <translation>Octecti:</translation>
+    </message>
     <message>
         <source>Amount:</source>
         <translation>Quantitas:</translation>
@@ -950,18 +984,10 @@
         <source>&amp;Label:</source>
         <translation>&amp;Titulus:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Glutina inscriptionem ex latibulo</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Nuntius:</translation>
@@ -984,18 +1010,10 @@
         <source>&amp;Sign Message</source>
         <translation>&amp;Signa Nuntium</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Glutina inscriptionem ex latibulo</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Insere hic nuntium quod vis signare</translation>
@@ -1110,10 +1128,6 @@
         <source>%1 confirmations</source>
         <translation>%1 confirmationes</translation>
     </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Dies</translation>
@@ -1256,10 +1270,6 @@
         <source>Mined</source>
         <translation>Fossa</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(nullus titulus)</translation>
@@ -1379,10 +1389,6 @@
         <source>Address</source>
         <translation>Inscriptio</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Range:</source>
         <translation>Intervallum:</translation>
@@ -1400,6 +1406,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>Creare novum casidillium</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1418,10 +1428,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Exporta data in hac tabella in plicam</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Conserva cassidile</translation>
