@@ -558,10 +558,6 @@
         <source>Use a custom data directory:</source>
         <translation>Izmantot pielāgotu datu mapi:</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Kļūda</translation>
@@ -588,15 +584,11 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>ielīmēt adresi no starpliktuves</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -804,34 +796,10 @@
         <source>%1 h</source>
         <translation>%1 st</translation>
     </message>
-    <message>
-        <source>%1 m</source>
-        <translation>%1 m</translation>
-    </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>%1 and %2</source>
         <translation>%1 un %2</translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation>nav zināms</translation>
@@ -846,10 +814,6 @@
     </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>Client version</source>
         <translation>Klienta versija</translation>
@@ -1154,18 +1118,10 @@
         <source>Choose previously used address</source>
         <translation>Izvēlies iepriekš izmantoto adresi</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>ielīmēt adresi no starpliktuves</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Remove this entry</source>
         <translation>Noņem šo ierakstu</translation>
@@ -1178,11 +1134,7 @@
         <source>Pay To:</source>
         <translation>Maksāt:</translation>
     </message>
-    <message>
-        <source>Memo:</source>
-        <translation>Memo:</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>ShutdownWindow</name>
     <message>
@@ -1204,18 +1156,10 @@
         <source>Choose previously used address</source>
         <translation>Izvēlies iepriekš izmantoto adresi</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>ielīmēt adresi no starpliktuves</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Šeit ievadi ziņojumu kuru vēlies parakstīt</translation>
@@ -1259,11 +1203,7 @@
     </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -1360,6 +1300,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Kļūda</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1378,10 +1322,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Datus no tekošā ieliktņa eksportēt uz failu</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Kļūda</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Maciņa Rezerves Kopija</translation>
