@@ -340,13 +340,6 @@
         <translation type="unfinished">Адреса</translation>
     </message>
 </context>
-<context>
-    <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
-    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -484,10 +477,6 @@
         <source>Number of connections</source>
         <translation>Број на конекции</translation>
     </message>
-    <message>
-        <source>Block chain</source>
-        <translation>Block chain</translation>
-    </message>
     <message>
         <source>Wallet: </source>
         <translation type="unfinished">Паричник: </translation>
@@ -642,6 +631,14 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Потврди порака</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Потврди порака</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -702,6 +699,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Грешка</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -716,10 +717,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Експортирај ги податоците од активното јазиче во датотека</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Грешка</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Бекап на Паричник</translation>
