@@ -800,8 +800,14 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>വാലറ്റ് / പണസഞ്ചി സൃഷ്ടിക്കുക :</translation>
+    </message>
     <message>
         <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
         <translation>വാലറ്റ് രൂപീകരിക്കുന്നു &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
     <message>
@@ -902,9 +908,6 @@
         <translation>ഡാറ്റ ഡയറക്ടറി ഇവിടെ സൃഷ്ടിക്കാൻ കഴിയില്ല.</translation>
     </message>
 </context>
-<context>
-    <name>GuiNetWatch</name>
-    </context>
 <context>
     <name>HelpMessageDialog</name>
     <message>
@@ -983,6 +986,11 @@
         <source>default wallet</source>
         <translation>സ്ഥിരം ആയ വാലറ്റ്</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>വാലറ്റ് തുറക്കുക </translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -1028,6 +1036,10 @@
         <source>Close</source>
         <translation type="unfinished">അടയ്ക്കുക</translation>
     </message>
+    <message>
+        <source>Signed transaction successfully. Transaction is ready to broadcast.</source>
+        <translation>ഇടപാട് വിജയകരമായി ഒപ്പിട്ടു.  ഇടപാട് പ്രക്ഷേപണത്തിന് തയ്യാറാണ്</translation>
+    </message>
     </context>
 <context>
     <name>PairingPage</name>
@@ -1122,6 +1134,10 @@
         <source>Node window</source>
         <translation>നോഡ് വിൻഡോ</translation>
     </message>
+    <message>
+        <source>Permissions</source>
+        <translation>അനുവാത്തംനൽകൾ</translation>
+    </message>
     <message>
         <source>Last block time</source>
         <translation>അവസാന ബ്ലോക്കിന്റെ സമയം </translation>
@@ -1165,6 +1181,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Request payment to ...</source>
+        <translation> പേയ്‌മെന്റ് അഭ്യർത്ഥിക്കുക...</translation>
+    </message>
     <message>
         <source>Address:</source>
         <translation type="unfinished">വിലാസം:</translation>
@@ -1298,10 +1318,6 @@
         <source>The Bitcoin address to send the payment to</source>
         <translation>പേയ്മെന്റ് അയക്കേണ്ട ബിറ്കോയിൻ അഡ്രസ് </translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     </context>
 <context>
     <name>ShutdownWindow</name>
@@ -1313,8 +1329,12 @@
         <translation>മുൻപ്‌ ഉപയോഗിച്ച അഡ്രസ് തെരഞ്ഞെടുക്കുക</translation>
     </message>
     <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Verify സന്ദേശം  …»»</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Verify സന്ദേശം  …»»</translation>
     </message>
     </context>
 <context>
@@ -1322,6 +1342,10 @@
     </context>
 <context>
     <name>TransactionDesc</name>
+    <message>
+        <source>%1 confirmations</source>
+        <translation type="unfinished">%1 സ്ഥിരീകരണങ്ങൾ</translation>
+    </message>
     <message>
         <source>Date</source>
         <translation>തീയതി </translation>
@@ -1412,7 +1436,11 @@
         <source>Create a new wallet</source>
         <translation>ഒരു പുതിയ വാലറ്റ് സൃഷ്ടിക്കുക</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>പിശക് </translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1430,10 +1458,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>പിശക് </translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">ബാക്കപ്പ് വാലറ്റ് </translation>
