@@ -229,9 +229,13 @@
         <source>&amp;Change Passphrase...</source>
         <translation>&amp;Нууц Үгийг Солих...</translation>
     </message>
+    <message>
+        <source>Create Wallet...</source>
+        <translation type="unfinished">Хэтэвч үүсгэх...</translation>
+    </message>
     <message>
         <source>Wallet:</source>
-        <translation type="unfinished">Түрүйвч:</translation>
+        <translation>Хэтэвч:</translation>
     </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
@@ -239,7 +243,12 @@
     </message>
     <message>
         <source>&amp;Send</source>
-        <translation type="unfinished">Яв&amp;уул</translation>
+        <translation>&amp;Илгээх
+ </translation>
+    </message>
+    <message>
+        <source>&amp;Receive</source>
+        <translation>&amp;Хүлээж авах</translation>
     </message>
     <message>
         <source>&amp;Show / Hide</source>
@@ -261,6 +270,10 @@
         <source>Error</source>
         <translation>Алдаа</translation>
     </message>
+    <message>
+        <source>Warning</source>
+        <translation>Анхааруулга</translation>
+    </message>
     <message>
         <source>Information</source>
         <translation>Мэдээллэл</translation>
@@ -281,6 +294,14 @@
         <source>&amp;Receiving addresses</source>
         <translation type="unfinished">&amp;Хүлээн авах хаяг</translation>
     </message>
+    <message>
+        <source>Close Wallet...</source>
+        <translation type="unfinished">Хэтэвч хаах...</translation>
+    </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Алдаа: %1</translation>
+    </message>
     <message>
         <source>Sent transaction</source>
         <translation>Гадагшаа гүйлгээ</translation>
@@ -351,9 +372,18 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation type="unfinished">Хэтэвч үүсгэх</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Create Wallet</source>
+        <translation type="unfinished">Хэтэвч үүсгэх</translation>
+    </message>
     <message>
         <source>Wallet</source>
         <translation>Түрүйвч</translation>
@@ -456,7 +486,7 @@
         <source>Paste address from clipboard</source>
         <translation>Копидсон хаягийг буулгах</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -529,6 +559,10 @@
         <source>N/A</source>
         <translation>Алга Байна</translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Алдаа: %1</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>үл мэдэгдэх</translation>
@@ -682,7 +716,7 @@
     </message>
     <message>
         <source>Wallet:</source>
-        <translation type="unfinished">Түрүйвч:</translation>
+        <translation>Хэтэвч:</translation>
     </message>
     <message>
         <source>Copy &amp;Address</source>
@@ -817,18 +851,10 @@
         <source>&amp;Label:</source>
         <translation>&amp;Шошго:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Копидсон хаягийг буулгах</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Зурвас:</translation>
@@ -847,22 +873,18 @@
 </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Копидсон хаягийг буулгах</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Clear &amp;All</source>
         <translation>&amp;Бүгдийг Цэвэрлэ</translation>
     </message>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation type="unfinished">&amp;Баталгаажуулах мэссэж</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -1103,6 +1125,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Алдаа</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1121,10 +1147,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Сонгогдсон таб дээрхи дата-г экспортлох</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Алдаа</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Түрүйвчийг Жоорлох</translation>
