@@ -379,6 +379,10 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Indexing blocks on disk...</source>
         <translation>Indexi blok pada cakera...</translation>
     </message>
+    <message numerus="yes">
+        <source>Processed %n block(s) of transaction history.</source>
+        <translation><numerusform>Processed %n blocks of transaction history.</numerusform></translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Ralat</translation>
@@ -419,9 +423,17 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Close wallet</source>
         <translation>Tutup Wallet</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
+    <message>
+        <source>Amount:</source>
+        <translation type="unfinished">Amount:</translation>
+    </message>
+    <message>
+        <source>Amount</source>
+        <translation type="unfinished">Amount</translation>
+    </message>
     <message>
         <source>&amp;Copy address</source>
         <translation>&amp;Salin Aamat</translation>
@@ -470,7 +482,19 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Error</source>
         <translation>Ralat</translation>
     </message>
-    </context>
+    <message numerus="yes">
+        <source>%n GB of free space available</source>
+        <translation><numerusform>%n GB of free space available</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>(of %n GB needed)</source>
+        <translation><numerusform>(of %n GB needed)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>(%n GB needed for full chain)</source>
+        <translation><numerusform>(%n GB needed for full chain)</numerusform></translation>
+    </message>
+</context>
 <context>
     <name>NetWatchLogModel</name>
     <message>
@@ -486,8 +510,14 @@ Alihkan fail data ke dalam tab semasa</translation>
         <translation>dompet lalai
 </translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Buka Wallet</translation>
+    </message>
     <message>
         <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
         <translation>Buka sedang Wallet &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
 </context>
@@ -502,6 +532,44 @@ Alihkan fail data ke dalam tab semasa</translation>
         <translation>Ralat</translation>
     </message>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished">Tutup</translation>
+    </message>
+    </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Amount</source>
+        <translation type="unfinished">Amount</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n second(s)</source>
+        <translation><numerusform>%n seconds</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minute(s)</source>
+        <translation><numerusform>%n minutes</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n hour(s)</source>
+        <translation><numerusform>%n hours</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n day(s)</source>
+        <translation><numerusform>%n days</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s)</source>
+        <translation><numerusform>%n weeks</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n year(s)</source>
+        <translation><numerusform>%n years</numerusform></translation>
+    </message>
+    </context>
 <context>
     <name>RPCConsole</name>
     <message>
@@ -524,6 +592,10 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
+    <message>
+        <source>&amp;Amount:</source>
+        <translation type="unfinished">&amp;Amount:</translation>
+    </message>
     <message>
         <source>&amp;Copy address</source>
         <translation>&amp;Salin Aamat</translation>
@@ -532,9 +604,17 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Copy &amp;label</source>
         <translation>Salin &amp;Label</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Address:</source>
+        <translation type="unfinished">Alamat:</translation>
+    </message>
+    <message>
+        <source>Amount:</source>
+        <translation type="unfinished">Amount:</translation>
+    </message>
     <message>
         <source>Wallet:</source>
         <translation>dompet</translation>
@@ -553,6 +633,10 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>SendCoinsDialog</name>
+    <message>
+        <source>Amount:</source>
+        <translation type="unfinished">Amount:</translation>
+    </message>
     <message>
         <source>Choose...</source>
         <translation type="unfinished">Pilih...</translation>
@@ -569,10 +653,18 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Cr&amp;eate Unsigned</source>
         <translation type="unfinished">&amp;Create Unsigned</translation>
     </message>
+    <message>
+        <source>Create Unsigned</source>
+        <translation type="unfinished">Create Unsigned</translation>
+    </message>
     <message>
         <source>Send</source>
         <translation type="unfinished">hantar</translation>
     </message>
+    <message numerus="yes">
+        <source>Estimated to begin confirmation within %n block(s).</source>
+        <translation><numerusform>Estimated to begin confirmation within %n blocks.</numerusform></translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(tiada label)</translation>
@@ -587,13 +679,29 @@ Alihkan fail data ke dalam tab semasa</translation>
     </context>
 <context>
     <name>TransactionDesc</name>
+    <message numerus="yes">
+        <source>Open for %n more block(s)</source>
+        <translation><numerusform>Open for %n more blocks</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>matures in %n more block(s)</source>
+        <translation><numerusform>matures in %n more blocks</numerusform></translation>
+    </message>
     <message>
         <source>Transaction</source>
         <translation>Transaksi</translation>
     </message>
+    <message>
+        <source>Amount</source>
+        <translation type="unfinished">Amount</translation>
+    </message>
     </context>
 <context>
     <name>TransactionTableModel</name>
+    <message numerus="yes">
+        <source>Open for %n more block(s)</source>
+        <translation><numerusform>Open for %n more blocks</numerusform></translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(tiada label)</translation>
@@ -628,7 +736,14 @@ Alihkan fail data ke dalam tab semasa</translation>
         <source>Close wallet</source>
         <translation>Tutup Wallet</translation>
     </message>
-</context>
+    </context>
+<context>
+    <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Ralat</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -648,10 +763,6 @@ Alihkan fail data ke dalam tab semasa</translation>
         <translation>
 Alihkan fail data ke dalam tab semasa</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Ralat</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Dompet Sandaran</translation>
@@ -672,4 +783,4 @@ Alihkan fail data ke dalam tab semasa</translation>
         <translation>Baca Selesai</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
