@@ -69,21 +69,9 @@
         <source>&amp;Edit</source>
         <translation>&amp;Alilan</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Comma separated file (*.csv)</translation>
-    </message>
     </context>
 <context>
     <name>AddressTableModel</name>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
-    <message>
-        <source>Address</source>
-        <translation>Address</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(alang label)</translation>
@@ -197,10 +185,6 @@
         <source>Synchronizing with network...</source>
         <translation>Mag-sychronize ne king network...</translation>
     </message>
-    <message>
-        <source>&amp;Overview</source>
-        <translation>&amp;Overview</translation>
-    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>Ipakit ing kabuuang lawe ning wallet</translation>
@@ -277,10 +261,6 @@
         <source>Show or hide the main Window</source>
         <translation>Ipalto o isalikut ing pun a awang</translation>
     </message>
-    <message>
-        <source>&amp;File</source>
-        <translation>&amp;File</translation>
-    </message>
     <message>
         <source>&amp;Settings</source>
         <translation>&amp;Pamag-ayus</translation>
@@ -337,10 +317,6 @@
         <source>&amp;Window</source>
         <translation>&amp;Awang</translation>
     </message>
-    <message>
-        <source>Catching up...</source>
-        <translation>Catching up...</translation>
-    </message>
     <message>
         <source>Sent transaction</source>
         <translation>Mipadalang transaksion</translation>
@@ -406,6 +382,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation type="unfinished">Wallet</translation>
+    </message>
     <message>
         <source>Encrypt Wallet</source>
         <translation type="unfinished">I-Encrypt in Wallet</translation>
@@ -417,14 +397,6 @@
         <source>Edit Address</source>
         <translation>Alilan ing Address</translation>
     </message>
-    <message>
-        <source>&amp;Label</source>
-        <translation>&amp;Label</translation>
-    </message>
-    <message>
-        <source>&amp;Address</source>
-        <translation>&amp;Address</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Bayung address king pamagpadala</translation>
@@ -470,10 +442,6 @@
         <source>Welcome</source>
         <translation>Malaus ka</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Mali</translation>
@@ -481,10 +449,6 @@
     </context>
 <context>
     <name>ModalOverlay</name>
-    <message>
-        <source>Form</source>
-        <translation>Form</translation>
-    </message>
     <message>
         <source>Unknown...</source>
         <translation type="unfinished">e miya balu...</translation>
@@ -501,14 +465,14 @@
         <comment>NetWatch: Type header</comment>
         <translation>Klase</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Idikit ing address menibat king clipboard</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -522,10 +486,6 @@
         <source>&amp;Main</source>
         <translation>&amp;Pun</translation>
     </message>
-    <message>
-        <source>&amp;Network</source>
-        <translation>&amp;Network</translation>
-    </message>
     <message>
         <source>W&amp;allet</source>
         <translation type="unfinished">&amp;Wallet</translation>
@@ -538,14 +498,6 @@
         <source>Map port using &amp;UPnP</source>
         <translation>Mapa ng ning port gamit ing &amp;UPnP</translation>
     </message>
-    <message>
-        <source>Proxy &amp;IP:</source>
-        <translation>Proxy &amp;IP:</translation>
-    </message>
-    <message>
-        <source>&amp;Port:</source>
-        <translation>&amp;Port:</translation>
-    </message>
     <message>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Port na ning proxy(e.g. 9050)</translation>
@@ -582,18 +534,10 @@
         <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
         <translation>Pilinan ing default subdivision unit a ipalto o ipakit king interface at istung magpadala kang barya.</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
-    </message>
     <message>
         <source>&amp;Cancel</source>
         <translation>I-&amp;Cancel</translation>
     </message>
-    <message>
-        <source>default</source>
-        <translation>default</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Kapilubluban ning Bitcoin</translation>
@@ -609,10 +553,6 @@
 </context>
 <context>
     <name>OverviewPage</name>
-    <message>
-        <source>Form</source>
-        <translation>Form</translation>
-    </message>
     <message>
         <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
         <translation>Ing makaltong impormasion mapalyaring luma ne. Ing kekang wallet otomatiku yang mag-synchronize keng Bitcoin network istung mekakonekta ne king network, oneng ing prosesung ini ali ya pa kumpletu.</translation>
@@ -625,10 +565,6 @@
         <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
         <translation>Ing kabuuan dareng transaksion a kasalungsungan ali pa me-kumpirma, at kasalungsungan ali pa mebilang kareng kekang balanseng malyari mung gastusan</translation>
     </message>
-    <message>
-        <source>Immature:</source>
-        <translation>Immature:</translation>
-    </message>
     <message>
         <source>Mined balance that has not yet matured</source>
         <translation>Reng me-minang balanse a epa meg-matured</translation>
@@ -668,10 +604,6 @@
         <source>Amount</source>
         <translation>Alaga</translation>
     </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation>e miya balu</translation>
@@ -687,10 +619,6 @@
     </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>Client version</source>
         <translation>Bersion ning Cliente</translation>
@@ -703,17 +631,13 @@
         <source>Startup time</source>
         <translation>Oras ning umpisa</translation>
     </message>
-    <message>
-        <source>Network</source>
-        <translation>Network</translation>
-    </message>
     <message>
         <source>Number of connections</source>
         <translation>Bilang dareng koneksion</translation>
     </message>
     <message>
-        <source>Block chain</source>
-        <translation>Block chain</translation>
+        <source>Wallet: </source>
+        <translation type="unfinished">Wallet: </translation>
     </message>
     <message>
         <source>Last block time</source>
@@ -723,14 +647,6 @@
         <source>&amp;Open</source>
         <translation>&amp;Ibuklat</translation>
     </message>
-    <message>
-        <source>&amp;Console</source>
-        <translation>&amp;Console</translation>
-    </message>
-    <message>
-        <source>Debug log file</source>
-        <translation>Debug log file</translation>
-    </message>
     <message>
         <source>Clear console</source>
         <translation>I-Clear ing console</translation>
@@ -759,10 +675,6 @@
         <source>&amp;Amount:</source>
         <translation>A&amp;laga:</translation>
     </message>
-    <message>
-        <source>&amp;Label:</source>
-        <translation>&amp;Label:</translation>
-    </message>
     <message>
         <source>&amp;Message:</source>
         <translation>&amp;Mensayi:</translation>
@@ -805,10 +717,6 @@
         <source>Date</source>
         <translation>Kaaldauan</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Message</source>
         <translation>Mensayi</translation>
@@ -907,22 +815,10 @@
         <source>Pay &amp;To:</source>
         <translation>Ibayad &amp;kang:</translation>
     </message>
-    <message>
-        <source>&amp;Label:</source>
-        <translation>&amp;Label:</translation>
-    </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Idikit ing address menibat king clipboard</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Mensayi:</translation>
@@ -945,18 +841,10 @@
         <source>&amp;Sign Message</source>
         <translation>&amp;Pirman ing Mensayi</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Idikit ing address menibat king clipboard</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Enter the message you want to sign here</source>
         <translation>Ipalub ing mensayi a buri mung pirman keni</translation>
@@ -1103,22 +991,10 @@
         <source>own address</source>
         <translation>sariling address</translation>
     </message>
-    <message>
-        <source>label</source>
-        <translation>label</translation>
-    </message>
-    <message>
-        <source>Credit</source>
-        <translation>Credit</translation>
-    </message>
     <message>
         <source>not accepted</source>
         <translation>ali metanggap</translation>
     </message>
-    <message>
-        <source>Debit</source>
-        <translation>Debit</translation>
-    </message>
     <message>
         <source>Transaction fee</source>
         <translation>Bayad king Transaksion</translation>
@@ -1177,10 +1053,6 @@
         <source>Type</source>
         <translation>Klase</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
     <message>
         <source>Open until %1</source>
         <translation>Makabuklat anggang %1</translation>
@@ -1213,10 +1085,6 @@
         <source>Mined</source>
         <translation>Me-mina</translation>
     </message>
-    <message>
-        <source>(n/a)</source>
-        <translation>(n/a)</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(alang label)</translation>
@@ -1308,10 +1176,6 @@
         <source>&amp;Show transaction details</source>
         <translation type="unfinished">&amp;Ipakit ing detalye ning transaksion</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Comma separated file (*.csv)</translation>
-    </message>
     <message>
         <source>Confirmed</source>
         <translation>Me-kumpirma</translation>
@@ -1324,18 +1188,6 @@
         <source>Type</source>
         <translation>Klase</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
-    <message>
-        <source>Address</source>
-        <translation>Address</translation>
-    </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Range:</source>
         <translation>Angga:</translation>
@@ -1353,6 +1205,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Mali</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1363,10 +1219,6 @@
     </context>
 <context>
     <name>WalletView</name>
-    <message>
-        <source>Error</source>
-        <translation>Mali</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">I-Backup ing Wallet</translation>
