@@ -446,10 +446,6 @@
         <source>Welcome</source>
         <translation>Miresevini</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Problem</translation>
@@ -485,7 +481,7 @@
         <source>Paste address from clipboard</source>
         <translation>Ngjit nga memorja e sistemit</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -712,18 +708,10 @@
         <source>&amp;Label:</source>
         <translation>&amp;Etiketë:</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Ngjit nga memorja e sistemit</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Pay To:</source>
         <translation>Paguaj drejt:</translation>
@@ -734,18 +722,10 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Ngjit nga memorja e sistemit</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -894,6 +874,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Problem</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -912,10 +896,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Eksporto të dhënat e skedës korrente në një skedar</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Problem</translation>
-    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
