@@ -226,10 +226,6 @@
 </context>
 <context>
     <name>BanTableModel</name>
-    <message>
-        <source>IP/Netmask</source>
-        <translation>IP/Netmask</translation>
-    </message>
     <message>
         <source>Banned Until</source>
         <translation>Banovani ste do</translation>
@@ -532,6 +528,9 @@
 <context>
     <name>FreespaceChecker</name>
     </context>
+<context>
+    <name>GuiNetWatch</name>
+    </context>
 <context>
     <name>HelpMessageDialog</name>
     <message>
@@ -541,10 +540,6 @@
     </context>
 <context>
     <name>Intro</name>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Greska</translation>
@@ -575,6 +570,11 @@
     </context>
 <context>
     <name>OpenWalletActivity</name>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>Otvori novčanik</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -809,6 +809,14 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;Proveri poruku</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;Proveri poruku</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -1037,6 +1045,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Greska</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1051,10 +1063,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Izvoz podataka iz trenutne kartice u datoteku</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Greska</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Rezervna Kopija Novčanika</translation>
