@@ -828,10 +828,6 @@
         <source>Use a custom data directory:</source>
         <translation>Użyj ôbranego folderu datōw</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
         <translation>Co nojmynij %1 GB datōw ôstanie spamiyntane w tym katalogu, daty te bydōm z czasym corŏz srogsze.</translation>
@@ -929,13 +925,6 @@
         <translation>Adresa</translation>
     </message>
 </context>
-<context>
-    <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
-</context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -1057,30 +1046,10 @@
         <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
         <translation>&amp;Skupluj bez proxy SOCKS5 (wychodne proxy):</translation>
     </message>
-    <message>
-        <source>Proxy &amp;IP:</source>
-        <translation>Proxy &amp;IP:</translation>
-    </message>
-    <message>
-        <source>&amp;Port:</source>
-        <translation>&amp;Port:</translation>
-    </message>
     <message>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Port ôd proxy (bp. 9050)</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>Ô&amp;kno</translation>
@@ -1097,10 +1066,6 @@
         <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
         <translation>Skupluj sie z necym Bitcoin ze pōmocōm ôsobnego proxy SOCKS5 dlŏ necu TOR</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
-    </message>
     <message>
         <source>&amp;Cancel</source>
         <translation>&amp;Pociep</translation>
@@ -1185,10 +1150,6 @@
         <source>User Agent</source>
         <translation>Agynt Używŏcza</translation>
     </message>
-    <message>
-        <source>Ping</source>
-        <translation>Ping</translation>
-    </message>
     <message>
         <source>Received</source>
         <translation>Ôdebrane</translation>
@@ -1212,46 +1173,6 @@
         <source>Inbound</source>
         <translation>Wchodowy</translation>
     </message>
-    <message>
-        <source>%1 d</source>
-        <translation>%1 d</translation>
-    </message>
-    <message>
-        <source>%1 h</source>
-        <translation>%1 h</translation>
-    </message>
-    <message>
-        <source>%1 m</source>
-        <translation>%1 m</translation>
-    </message>
-    <message>
-        <source>%1 s</source>
-        <translation>%1 s</translation>
-    </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
-    <message>
-        <source>%1 ms</source>
-        <translation>%1 ms</translation>
-    </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>Error: %1</source>
         <translation>Feler: %1</translation>
@@ -1282,10 +1203,6 @@
 </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>Client version</source>
         <translation>Wersyjŏ klijynta</translation>
@@ -1666,14 +1583,6 @@
         <source>The Bitcoin address to send the payment to</source>
         <translation>Adresa Bitcoin, na kerõ chcesz posłać płat</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Use available balance</source>
         <translation>Użyj dostympnego salda</translation>
@@ -1700,14 +1609,6 @@
         <source>&amp;Sign Message</source>
         <translation>&amp;Szkryftnij Wiadōmość</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Sign &amp;Message</source>
         <translation>Szkryftnij &amp;Wiadōmość</translation>
@@ -1735,11 +1636,7 @@
     </context>
 <context>
     <name>TrafficGraphWidget</name>
-    <message>
-        <source>KB/s</source>
-        <translation>KB/s</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message>
@@ -1887,10 +1784,6 @@
         <source>Address</source>
         <translation>Adresa</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>Eksportowanie niy podarziło sie</translation>
@@ -1908,6 +1801,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Feler</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1934,10 +1831,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Eksportuj dane z aktywnyj szkarty do zbioru</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Feler</translation>
-    </message>
     <message>
         <source>Backup Failed</source>
         <translation>Backup niy podarził sie</translation>
@@ -1957,10 +1850,6 @@
         <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
         <translation>Pozōr: Nec niy wydŏwŏ sie w połni zgodliwy! Niykerzi grubiŏrze wydajōm sie doświadczać niyprzileżytości.</translation>
     </message>
-    <message>
-        <source>Copyright (C) %i-%i</source>
-        <translation>Copyright (C) %i-%i</translation>
-    </message>
     <message>
         <source>Error loading %s</source>
         <translation>Feler wgrŏwaniŏ %s</translation>
