@@ -175,10 +175,6 @@
         <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
         <translation>వాలెట్ కోసం క్రొత్త పాస్‌ఫ్రేజ్‌ని నమోదు చేయండి.&lt;br/&gt; దయచేసి &lt;b&gt;పది లేదా అంతకంటే ఎక్కువ యాదృచ్ఛిక అక్షరాల&lt;/b&gt; పాస్‌ఫ్రేజ్‌ని లేదా &lt;b&gt;ఎనిమిది లేదా అంతకంటే ఎక్కువ పదాలను ఉపయోగించండి.&lt;/b&gt;</translation>
     </message>
-    <message>
-        <source>Enter the old passphrase and new passphrase for the wallet.</source>
-        <translation>Enter the old passphrase and new passphrase for the wallet.</translation>
-    </message>
     <message>
         <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
         <translation>మీ వాలెట్‌ను గుప్తీకరించడం వల్ల మీ కంప్యూటర్‌కు హాని కలిగించే మాల్వేర్ దొంగిలించకుండా మీ బిట్‌కాయిన్‌లను పూర్తిగా రక్షించలేమని గుర్తుంచుకోండి.</translation>
@@ -432,6 +428,11 @@
     </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation type="unfinished">జోలెను సృష్టించండి</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
@@ -727,6 +728,10 @@
         <source>Merchant</source>
         <translation>వర్తకుడు</translation>
     </message>
+    <message>
+        <source>Transaction</source>
+        <translation>లావాదేవీ</translation>
+    </message>
     <message>
         <source>Amount</source>
         <translation>మొత్తం</translation>
@@ -797,7 +802,11 @@
         <source>Create a new wallet</source>
         <translation>&lt;div&gt;&lt;/div&gt;</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>లోపం</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     </context>
@@ -811,10 +820,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>ప్రస్తుతం ఉన్న సమాచారాన్ని ఫైల్ లోనికి ఎగుమతి చేసుకోండి</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>లోపం</translation>
-    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
