@@ -187,12 +187,12 @@
         <source>Wallet decryption failed</source>
         <translation>การถอดรหัสกระเป๋าสตางค์ล้มเหลว</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>BanTableModel</name>
     <message>
         <source>IP/Netmask</source>
-        <translation>IP/Netmask</translation>
+        <translation>IP/Netmask (ตัวกรอง IP)</translation>
     </message>
     <message>
         <source>Banned Until</source>
@@ -285,11 +285,6 @@
         <source>Wallet:</source>
         <translation>กระเป๋าสตางค์:</translation>
     </message>
-    <message>
-        <source>Network activity disabled.</source>
-        <extracomment>A substring of the tooltip.</extracomment>
-        <translation>Network activity disabled.</translation>
-    </message>
     <message>
         <source>Syncing Headers (%1%)...</source>
         <translation>กำลังซิงค์ส่วนหัว (%1%)...</translation>
@@ -426,6 +421,10 @@
         <source>Node window</source>
         <translation>หน้าต่างโหนด</translation>
     </message>
+    <message>
+        <source>Open node debugging and diagnostic console</source>
+        <translation>เปิด แผลงควบคุม debugging และ diagnostic</translation>
+    </message>
     <message>
         <source>&amp;Sending addresses</source>
         <translation>&amp;ที่อยู่การส่ง</translation>
@@ -462,14 +461,6 @@
         <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
         <translation>แสดง %1 ข้อความช่วยเหลือ เพื่อแสดงรายการ ตัวเลือกที่เป็นไปได้สำหรับ Bitcoin command-line</translation>
     </message>
-    <message>
-        <source>&amp;Mask values</source>
-        <translation>&amp;Mask values</translation>
-    </message>
-    <message>
-        <source>Mask the values in the Overview tab</source>
-        <translation>Mask the values in the Overview tab</translation>
-    </message>
     <message>
         <source>No wallets available</source>
         <translation>ไม่มีกระเป๋าสตางค์</translation>
@@ -567,6 +558,10 @@
         <source>Original message:</source>
         <translation>ข้อความดั้งเดิม:</translation>
     </message>
+    <message>
+        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
+        <translation>เกิดข้อผิดพลาดร้ายแรง %1 ไม่สามารถดำเนินการต่อได้อย่างปลอดภัยอีกต่อไปและจะยกเลิก</translation>
+    </message>
 </context>
 <context>
     <name>CoinControlDialog</name>
@@ -662,10 +657,6 @@
         <source>L&amp;ock unspent</source>
         <translation type="unfinished">&amp;Lock unspent</translation>
     </message>
-    <message>
-        <source>Can vary +/- %1 satoshi(s) per input.</source>
-        <translation>Can vary +/- %1 satoshi(s) per input.</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(ไม่มีป้ายชื่อ)</translation>
@@ -681,11 +672,17 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>สร้างกระเป๋าสตางค์</translation>
+    </message>
     <message>
         <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
         <translation>กำลังสร้างกระเป๋าสตางค์ &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>CreateWalletDialog</name>
     <message>
@@ -755,7 +752,7 @@
         <source>Could not unlock wallet.</source>
         <translation>ไม่สามารถปลดล็อคกระเป๋าสตางค์</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>FreespaceChecker</name>
     <message>
@@ -816,14 +813,17 @@
         <source>Use a custom data directory:</source>
         <translation>ใช้ไดเรกทอรีข้อมูลที่กำหนดเอง:</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Approximately %1 GB of data will be stored in this directory.</source>
         <translation>ประมาณ %1 GB ของข้อมูลจะเก็บในไดเร็กทอรี่</translation>
     </message>
+    <message numerus="yes">
+        <source>(sufficient to restore backups %n day(s) old)</source>
+        <comment>block chain pruning</comment>
+        <translation type="unfinished">
+            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
+        </translation>
+    </message>
     <message>
         <source>The wallet will also be stored in this directory.</source>
         <translation>The wallet เก็บใว้ในไดเร็กทอรี่</translation>
@@ -849,9 +849,6 @@
         <translation><numerusform>(%n GB needed for full chain)</numerusform></translation>
     </message>
 </context>
-<context>
-    <name>MempoolStats</name>
-    </context>
 <context>
     <name>ModalOverlay</name>
     <message>
@@ -870,7 +867,7 @@
         <source>Hide</source>
         <translation>ซ่อน</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>NetWatchLogModel</name>
     <message>
@@ -886,23 +883,25 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>วางที่อยู่จากคลิปบอร์ด</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
         <source>default wallet</source>
         <translation>กระเป๋าสตางค์เริ่มต้น</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>เปิดกระเป๋าสตางค์</translation>
+    </message>
     <message>
         <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
         <translation>กำลังเปิดกระเป๋าสตางค์ &lt;b&gt;%1&lt;/b&gt;...</translation>
     </message>
 </context>
@@ -1020,18 +1019,6 @@
         <source>Used for reaching peers via:</source>
         <translation>ใช้ในการเข้าถึงอีกฝ่ายหนึ่ง peer โดย:</translation>
     </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Tor</source>
-        <translation>Tor</translation>
-    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;หน้าต่าง</translation>
@@ -1044,6 +1031,10 @@
         <source>User Interface &amp;language:</source>
         <translation>&amp;ภาษาส่วนติดต่อผู้ใช้:</translation>
     </message>
+    <message>
+        <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
+        <translation>เชื่อมต่อกับ เครือข่าย Bitcoin ผ่านทาง พร้อกซี่ SOCKS5 แยกต่างหาก สำหรับ Tor เซอร์วิส</translation>
+    </message>
     <message>
         <source>&amp;OK</source>
         <translation>&amp;ตกลง</translation>
@@ -1060,7 +1051,7 @@
         <source>Error</source>
         <translation>ข้อผิดพลาด</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OverviewPage</name>
     <message>
@@ -1071,7 +1062,7 @@
         <source>Balances</source>
         <translation>ยอดดุล</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>PSBTOperationsDialog</name>
     <message>
@@ -1086,10 +1077,7 @@
         <source>Close</source>
         <translation>ปิด</translation>
     </message>
-</context>
-<context>
-    <name>PaymentServer</name>
-</context>
+    </context>
 <context>
     <name>PeerTableModel</name>
     <message>
@@ -1142,9 +1130,17 @@
         <source>Save QR Code</source>
         <translation>บันทึกรหัส QR</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>RPCConsole</name>
+    <message>
+        <source>&amp;Information</source>
+        <translation type="unfinished">&amp;ข้อมูล</translation>
+    </message>
+    <message>
+        <source>Network</source>
+        <translation type="unfinished">เน็ตเวิร์ก</translation>
+    </message>
     <message>
         <source>Wallet: </source>
         <translation>กระเป๋าสตางค์: </translation>
@@ -1181,6 +1177,10 @@
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
+    <message>
+        <source>&amp;Amount:</source>
+        <translation type="unfinished">&amp;จำนวน:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;ป้ายชื่อ:</translation>
@@ -1225,7 +1225,7 @@
         <source>Could not unlock wallet.</source>
         <translation>ไม่สามารถปลดล็อคกระเป๋าสตางค์</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
@@ -1256,7 +1256,7 @@
         <source>Copy &amp;Address</source>
         <translation>&amp;คัดลอกที่อยู่</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>RecentRequestsTableModel</name>
     <message>
@@ -1275,7 +1275,7 @@
         <source>(no label)</source>
         <translation>(ไม่มีป้ายชื่อ)</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>SendCoinsDialog</name>
     <message>
@@ -1326,6 +1326,10 @@
         <source>Dust:</source>
         <translation>เศษ:</translation>
     </message>
+    <message>
+        <source>S&amp;end</source>
+        <translation type="unfinished">&amp;ส่ง</translation>
+    </message>
     <message>
         <source>Copy amount</source>
         <translation>คัดลอกจำนวนเงิน</translation>
@@ -1349,6 +1353,10 @@
 </context>
 <context>
     <name>SendCoinsEntry</name>
+    <message>
+        <source>A&amp;mount:</source>
+        <translation type="unfinished">&amp;จำนวน:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;ป้ายชื่อ:</translation>
@@ -1361,12 +1369,13 @@
         <source>Message:</source>
         <translation>ข้อความ:</translation>
     </message>
-</context>
-<context>
-    <name>ShutdownWindow</name>
-</context>
+    </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>&amp;Sign Message</source>
+        <translation type="unfinished">&amp;เซ็นข้อความ</translation>
+    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>วางที่อยู่จากคลิปบอร์ด</translation>
@@ -1379,14 +1388,19 @@
         <source>Sign &amp;Message</source>
         <translation>&amp;เซ็นข้อความ</translation>
     </message>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;ยืนยันข้อความ</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;ยืนยันข้อความ</translation>
+    </message>
     <message>
         <source>No error</source>
         <translation>ไม่มีข้อผิดพลาด</translation>
     </message>
-</context>
-<context>
-    <name>TrafficGraphWidget</name>
-</context>
+    </context>
 <context>
     <name>TransactionDesc</name>
     <message numerus="yes">
@@ -1421,14 +1435,15 @@
         <source>Comment</source>
         <translation>ความคิดเห็น</translation>
     </message>
+    <message>
+        <source>Transaction</source>
+        <translation>การทำรายการ</translation>
+    </message>
     <message>
         <source>Amount</source>
         <translation>จำนวน</translation>
     </message>
-</context>
-<context>
-    <name>TransactionDescDialog</name>
-</context>
+    </context>
 <context>
     <name>TransactionTableModel</name>
     <message>
@@ -1451,7 +1466,7 @@
         <source>(no label)</source>
         <translation>(ไม่มีป้ายชื่อ)</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>TransactionView</name>
     <message>
@@ -1514,10 +1529,6 @@
         <source>&amp;Edit label</source>
         <translation type="unfinished">&amp;แก้ไขป้ายชื่อ</translation>
     </message>
-    <message>
-        <source>&amp;Show transaction details</source>
-        <translation type="unfinished">&amp;Show transaction details</translation>
-    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>ไฟล์ที่คั่นด้วยจุลภาค (* .csv)</translation>
@@ -1546,10 +1557,7 @@
         <source>Exporting Failed</source>
         <translation>การส่งออกล้มเหลว</translation>
     </message>
-</context>
-<context>
-    <name>UnitDisplayStatusBarControl</name>
-</context>
+    </context>
 <context>
     <name>WalletController</name>
     <message>
@@ -1571,7 +1579,11 @@
         <source>Create a new wallet</source>
         <translation>สร้างกระเป๋าสตางค์</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>ข้อผิดพลาด</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1597,10 +1609,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>ส่งออกข้อมูลในแท็บปัจจุบันไปยังไฟล์</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>ข้อผิดพลาด</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>สำรองข้อมูลกระเป๋าสตางค์</translation>
@@ -1640,9 +1648,5 @@
         <source>Loading wallet...</source>
         <translation>กำลังโหลดกระเป๋าสตางค์...</translation>
     </message>
-    <message>
-        <source>Rescanning...</source>
-        <translation>Rescanning...</translation>
-    </message>
-</context>
+    </context>
 </TS>
\ No newline at end of file
