@@ -699,10 +699,6 @@
         <source>Use a custom data directory:</source>
         <translation>Бошқа маълумотлар директориясида фойдаланинг:</translation>
     </message>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
         <translation>Камида %1GB  маълумот ушбу директорияга жойлаштирилади ва вақт давомида ўсиб боради.</translation>
@@ -761,15 +757,11 @@
 </context>
 <context>
     <name>OpenURIDialog</name>
-    <message>
-        <source>URI:</source>
-        <translation>URI:</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Клипбоарддан манзилни қўйиш</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     </context>
@@ -855,10 +847,6 @@
         <source>&amp;Third party transaction URLs</source>
         <translation type="unfinished">&amp;Бегона тараф ўтказмалари URL манзиллари</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
-    </message>
     <message>
         <source>&amp;Cancel</source>
         <translation>&amp;Бекор қилиш</translation>
@@ -1317,6 +1305,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Request payment to ...</source>
+        <translation type="unfinished">... дан Тўловни сўраш</translation>
+    </message>
     <message>
         <source>Address:</source>
         <translation type="unfinished">Манзил:</translation>
@@ -1558,18 +1550,10 @@
         <source>Choose previously used address</source>
         <translation>Олдин фойдаланилган манзилни танла</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Клипбоарддан манзилни қўйиш</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Message:</source>
         <translation>Хабар</translation>
@@ -1588,18 +1572,10 @@
         <source>Choose previously used address</source>
         <translation>Олдин фойдаланилган манзилни танла</translation>
     </message>
-    <message>
-        <source>Alt+A</source>
-        <translation>Alt+A</translation>
-    </message>
     <message>
         <source>Paste address from clipboard</source>
         <translation>Клипбоарддан манзилни қўйиш</translation>
     </message>
-    <message>
-        <source>Alt+P</source>
-        <translation>Alt+P</translation>
-    </message>
     <message>
         <source>Signature</source>
         <translation>Имзо</translation>
@@ -1608,6 +1584,14 @@
         <source>Clear &amp;All</source>
         <translation>Барчасини &amp; Тозалаш</translation>
     </message>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>Хабарни &amp;тасдиқлаш</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">Хабарни &amp;тасдиқлаш</translation>
+    </message>
     <message>
         <source>Message verified.</source>
         <translation>Хабар тасдиқланди.</translation>
@@ -1907,10 +1891,6 @@
         <source>Address</source>
         <translation>Манзил</translation>
     </message>
-    <message>
-        <source>ID</source>
-        <translation>ID</translation>
-    </message>
     <message>
         <source>Exporting Failed</source>
         <translation>Экспорт қилиб бўлмади</translation>
@@ -1936,6 +1916,10 @@
     </context>
 <context>
     <name>WalletFrame</name>
+    <message>
+        <source>Error</source>
+        <translation>Хатолик</translation>
+    </message>
     </context>
 <context>
     <name>WalletModel</name>
@@ -1954,10 +1938,6 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Жорий ички ойна ичидаги маълумотларни файлга экспорт қилиш</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>Хатолик</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">Ҳамённи заҳиралаш</translation>
