@@ -297,6 +297,10 @@
         <source>&amp;Options...</source>
         <translation>&amp;选项</translation>
     </message>
+    <message>
+        <source>Modify configuration options for %1</source>
+        <translation>配置选项%1</translation>
+    </message>
     <message>
         <source>&amp;Encrypt Wallet...</source>
         <translation>&amp;加密钱包...</translation>
@@ -458,6 +462,14 @@
         <source>Up to date</source>
         <translation>最新的</translation>
     </message>
+    <message>
+        <source>&amp;Load PSBT from file...</source>
+        <translation type="unfinished">从文件加载PSBT...</translation>
+    </message>
+    <message>
+        <source>Load PSBT from clipboard...</source>
+        <translation type="unfinished">从剪贴板加载PSBT...</translation>
+    </message>
     <message>
         <source>Node window</source>
         <translation>结点窗口</translation>
@@ -599,7 +611,11 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>钱包是&lt;b&gt;加密的&lt;/b&gt;，目前&lt;b&gt;已锁定&lt;/b&gt;</translation>
     </message>
-    </context>
+    <message>
+        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
+        <translation>发生致命错误。%1 已经无法继续安全运行并即将退出。</translation>
+    </message>
+</context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -745,6 +761,11 @@
     </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation>创建钱包</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
@@ -964,8 +985,14 @@
         <source>default wallet</source>
         <translation>默认钱包</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>打开钱包</translation>
+    </message>
     <message>
         <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
         <translation>正在打开钱包&lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
 </context>
@@ -1073,6 +1100,10 @@
         <source>Amount</source>
         <translation>总计</translation>
     </message>
+    <message>
+        <source>%1 didn't yet exit safely...</source>
+        <translation type="unfinished">%1 没有安全退出...</translation>
+    </message>
     <message>
         <source>Txn</source>
         <comment>Tx Watch: Transaction type abbreviation</comment>
@@ -1081,6 +1112,10 @@
 </context>
 <context>
     <name>QRImageWidget</name>
+    <message>
+        <source>Error encoding URI into QR Code.</source>
+        <translation>错误地将 URI 编码成二维码</translation>
+    </message>
     </context>
 <context>
     <name>RPCConsole</name>
@@ -1088,6 +1123,10 @@
         <source>&amp;Information</source>
         <translation type="unfinished">&amp;消息</translation>
     </message>
+    <message>
+        <source>Blocksdir</source>
+        <translation>区块目录</translation>
+    </message>
     <message>
         <source>Network</source>
         <translation type="unfinished">网络</translation>
@@ -1437,6 +1476,14 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Choose previously used address</source>
         <translation>选择以前使用的地址</translation>
     </message>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>&amp;验证消息</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">&amp;验证消息</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -1455,6 +1502,10 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Message</source>
         <translation>消息</translation>
     </message>
+    <message>
+        <source>Transaction</source>
+        <translation>转账</translation>
+    </message>
     <message>
         <source>Amount</source>
         <translation>总计</translation>
@@ -1496,6 +1547,10 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Copy transaction &amp;ID</source>
         <translation type="unfinished">&amp;复制交易 ID</translation>
     </message>
+    <message>
+        <source>&amp;Edit label</source>
+        <translation type="unfinished">&amp;编辑标签</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>逗号分隔的文件 (*.csv)</translation>
@@ -1537,7 +1592,11 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Create a new wallet</source>
         <translation>创建一个新的钱包</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>错误</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1555,10 +1614,6 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Export the data in the current tab to a file</source>
         <translation>将当前选项卡中的数据导出到文件</translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation>错误</translation>
-    </message>
     <message>
         <source>Backup Wallet</source>
         <translation type="unfinished">备份钱包</translation>
@@ -1570,6 +1625,10 @@ Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis p
         <source>Error</source>
         <translation>错误</translation>
     </message>
+    <message>
+        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
+        <translation>所有端口均监听失败。如果这是预料之中的，使用 -listen=0 。</translation>
+    </message>
     <message>
         <source>Loading P2P addresses...</source>
         <translation>正在载入地址...</translation>
