@@ -463,6 +463,11 @@
     </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create Wallet</source>
+        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
+        <translation type="unfinished">建立錢包</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
@@ -493,6 +498,9 @@
 <context>
     <name>FreespaceChecker</name>
     </context>
+<context>
+    <name>GuiNetWatch</name>
+    </context>
 <context>
     <name>HelpMessageDialog</name>
     <message>
@@ -502,10 +510,6 @@
     </context>
 <context>
     <name>Intro</name>
-    <message>
-        <source>Bitcoin</source>
-        <translation>Bitcoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>錯誤</translation>
@@ -531,6 +535,11 @@
         <source>default wallet</source>
         <translation>預設錢包</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
+        <translation>開啟錢包</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -596,10 +605,6 @@
         <source>None</source>
         <translation>沒有</translation>
     </message>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>%1 ms</source>
         <translation>%1 亳秒</translation>
@@ -660,10 +665,6 @@
 </context>
 <context>
     <name>RPCConsole</name>
-    <message>
-        <source>N/A</source>
-        <translation>N/A</translation>
-    </message>
     <message>
         <source>&amp;Information</source>
         <translation>資訊 &amp;I</translation>
@@ -770,6 +771,14 @@
     </context>
 <context>
     <name>SignVerifyMessageDialog</name>
+    <message>
+        <source>&amp;Verify Message</source>
+        <translation>驗證訊息 &amp;V</translation>
+    </message>
+    <message>
+        <source>Verify &amp;Message</source>
+        <translation type="unfinished">驗證訊息 &amp;V</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -846,7 +855,11 @@
         <source>Create a new wallet</source>
         <translation>新增一個錢包</translation>
     </message>
-</context>
+    <message>
+        <source>Error</source>
+        <translation>錯誤</translation>
+    </message>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -865,8 +878,8 @@
         <translation>把目前分頁的資料匯出至檔案</translation>
     </message>
     <message>
-        <source>Error</source>
-        <translation>錯誤</translation>
+        <source>Backup Wallet</source>
+        <translation>備份錢包 &amp;B</translation>
     </message>
     </context>
 <context>
