@@ -742,9 +742,10 @@ void RPCConsole::setClientModel(ClientModel *model, int bestblock_height, int64_
         ui->peerWidget->setColumnWidth(PeerTableModel::NetNodeId, GUIUtil::TextWidth(fm, "99999"));
         ui->peerWidget->setColumnWidth(PeerTableModel::Direction, DIRECTION_COLUMN_WIDTH);
         ui->peerWidget->setColumnWidth(PeerTableModel::Address, ADDRESS_COLUMN_WIDTH);
-        ui->peerWidget->setColumnWidth(PeerTableModel::ConnectionType, GUIUtil::TextWidth(fm, "Address Fetch"));
-        ui->peerWidget->setColumnWidth(PeerTableModel::Sent, GUIUtil::TextWidth(fm, "1023 GBx"));
-        ui->peerWidget->setColumnWidth(PeerTableModel::Received, GUIUtil::TextWidth(fm, "1023 GBx"));
+        ui->peerWidget->setColumnWidth(PeerTableModel::ConnectionType, GUIUtil::TextWidth(fm, GUIUtil::ConnectionTypeToShortQString(ConnectionType::ADDR_FETCH /* TODO: Find the longest string? */, /* relay_txes */ false)));
+        const auto bytesize_width = GUIUtil::TextWidth(fm, GUIUtil::formatBytes(999000000000ull) + "x");
+        ui->peerWidget->setColumnWidth(PeerTableModel::Sent, bytesize_width);
+        ui->peerWidget->setColumnWidth(PeerTableModel::Received, bytesize_width);
         ui->peerWidget->setColumnWidth(PeerTableModel::Subversion, SUBVERSION_COLUMN_WIDTH);
         ui->peerWidget->setColumnWidth(PeerTableModel::Ping, PING_COLUMN_WIDTH);
         ui->peerWidget->horizontalHeader()->setStretchLastSection(true);
@@ -762,7 +763,8 @@ void RPCConsole::setClientModel(ClientModel *model, int bestblock_height, int64_
         // create peer table context menu
         peersTableContextMenu = new QMenu(this);
         //: Context menu action to copy the address of a peer
-        peersTableContextMenu->addAction(tr("&Copy address"), [this] {
+        QAction* const copy_address_action = peersTableContextMenu->addAction(tr("&Copy address"));
+        connect(copy_address_action, &QAction::triggered, [this] {
             GUIUtil::copyEntryData(ui->peerWidget, PeerTableModel::Address, Qt::DisplayRole);
         });
         peersTableContextMenu->addSeparator();
