@@ -10,7 +10,6 @@
 #include <httpserver.h>
 #include <index/blockfilterindex.h>
 #include <index/txindex.h>
-#include <net_processing.h>
 #include <node/context.h>
 #include <optional.h>
 #include <primitives/block.h>
@@ -34,6 +33,7 @@
 #include <univalue.h>
 
 static const size_t MAX_GETUTXOS_OUTPOINTS = 15; //allow a max of 15 outpoints to be queried at once
+static constexpr unsigned int MAX_REST_HEADERS_RESULTS = 2000;
 
 enum class RetFormat {
     UNDEF,
@@ -318,7 +318,7 @@ static bool rest_filter_header(const util::Ref& context, HTTPRequest* req, const
     std::vector<std::string> uriParts;
     boost::split(uriParts, param, boost::is_any_of("/"));
     if (uriParts.size() != 3) {
-        return RESTERR(req, HTTP_BAD_REQUEST, "Invalid URI format. Expected /rest/blockfilterheaders/filtertype/count/blockhash");
+        return RESTERR(req, HTTP_BAD_REQUEST, "Invalid URI format. Expected /rest/blockfilterheaders/<filtertype>/<count>/<blockhash>");
     }
 
     uint256 block_hash;
@@ -336,9 +336,10 @@ static bool rest_filter_header(const util::Ref& context, HTTPRequest* req, const
         return RESTERR(req, HTTP_BAD_REQUEST, "Index is not enabled for filtertype " + uriParts[0]);
     }
 
-    long count = strtol(uriParts[1].c_str(), nullptr, 10);
-    if (count < 1 || (unsigned long)count > MAX_HEADERS_RESULTS) {
-        return RESTERR(req, HTTP_BAD_REQUEST, strprintf("Header count out of acceptable range (1-%u): %s",  MAX_HEADERS_RESULTS, uriParts[1]));
+    uint32_t count;
+    const auto parsed_count = ParseUInt32(uriParts[1], &count) ? Optional<size_t>(size_t(count)) : Optional<size_t>{};
+    if (!parsed_count.has_value() || count < 1 || count > MAX_REST_HEADERS_RESULTS) {
+        return RESTERR(req, HTTP_BAD_REQUEST, strprintf("Header count out of acceptable range (1-%u): %s", MAX_REST_HEADERS_RESULTS, uriParts[1]));
     }
 
     std::vector<const CBlockIndex *> headers;
@@ -426,7 +427,7 @@ static bool rest_block_filter(const util::Ref& context, HTTPRequest* req, const
     std::vector<std::string> uriParts;
     boost::split(uriParts, param, boost::is_any_of("/"));
     if (uriParts.size() != 2) {
-        return RESTERR(req, HTTP_BAD_REQUEST, "Invalid URI format. Expected /rest/blockfilter/filtertype/blockhash");
+        return RESTERR(req, HTTP_BAD_REQUEST, "Invalid URI format. Expected /rest/blockfilter/<filtertype>/<blockhash>");
     }
 
     uint256 block_hash;
