@@ -25,6 +25,11 @@
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/algorithm/string/replace.hpp>
 #ifdef HAVE_BOOST_PROCESS
+#if defined(WIN32) && !defined(__kernel_entry)
+// A workaround for boost 1.71 incompatibility with mingw-w64 compiler.
+// For details see https://github.com/bitcoin/bitcoin/pull/22348.
+#define __kernel_entry
+#endif
 #include <boost/process.hpp>
 #endif
 
@@ -797,7 +802,11 @@ std::string TorController::LaunchTor()
 
     boost::process::opstream in;
     try {
-        m_process = new boost::process::child(m_execute + " -f -", boost::process::std_in < in);
+        m_process = new boost::process::child(m_execute + " -f -", boost::process::std_in < in
+#ifdef HAVE_BPE_CLOSE_EXCESS_FDS
+            , bpe_close_excess_fds()
+#endif
+        );
     } catch (...) {
         LogPrint(BCLog::TOR, "tor: Failed to execute Tor process\n");
         throw;
