@@ -7,6 +7,11 @@
 #include <util/system.h>
 
 #ifdef HAVE_BOOST_PROCESS
+#if defined(WIN32) && !defined(__kernel_entry)
+// A workaround for boost 1.71 incompatibility with mingw-w64 compiler.
+// For details see https://github.com/bitcoin/bitcoin/pull/22348.
+#define __kernel_entry
+#endif
 #include <boost/process.hpp>
 #endif // HAVE_BOOST_PROCESS
 
@@ -1542,6 +1547,9 @@ UniValue RunCommandParseJSON(const std::string& str_command, const std::string&
         bp::std_out > stdout_stream,
         bp::std_err > stderr_stream,
         bp::std_in < stdin_stream
+#ifdef HAVE_BPE_CLOSE_EXCESS_FDS
+        , bpe_close_excess_fds()
+#endif
     );
     if (!str_std_in.empty()) {
         stdin_stream << str_std_in << std::endl;
@@ -1576,7 +1584,7 @@ void SetupEnvironment()
 #endif
     // On most POSIX systems (e.g. Linux, but not BSD) the environment's locale
     // may be invalid, in which case the "C.UTF-8" locale is used as fallback.
-#if !defined(WIN32) && !defined(MAC_OSX) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
+#if !defined(WIN32) && !defined(MAC_OSX) && !defined(__FreeBSD__) && !defined(__OpenBSD__) && !defined(__NetBSD__)
     try {
         std::locale(""); // Raises a runtime error if current locale is invalid
     } catch (const std::runtime_error&) {
