@@ -336,6 +336,8 @@ static void RemoveScript(CWallet* const pwallet, const CScript& script, bool is_
 
     LegacyScriptPubKeyMan& spk_man = EnsureLegacyScriptPubKeyMan(*pwallet);
 
+    throw JSONRPCError(RPC_INTERNAL_ERROR, "removeaddress is broken, sorry");
+
     if (spk_man.HaveWatchOnly(script) && !spk_man.PurgeWatchOnly(script)) {
         throw JSONRPCError(RPC_WALLET_ERROR, "Error removing address/script from wallet");
     }
@@ -1759,7 +1761,7 @@ RPCHelpMan importdescriptors()
                                         /* oneline_description */ "", {"timestamp | \"now\"", "integer / string"}
                                     },
                                     {"internal", RPCArg::Type::BOOL, /* default */ "false", "Whether matching outputs should be treated as not incoming payments (e.g. change)"},
-                                    {"label", RPCArg::Type::STR, /* default */ "''", "Label to assign to the address, only allowed with internal=false"},
+                                    {"label", RPCArg::Type::STR, /* default */ "''", "Label to assign to the address, only allowed with internal=false. Disabled for ranged descriptors"},
                                 },
                             },
                         },
