@@ -626,6 +626,7 @@ class WalletTest(BitcoinTestFramework):
                                 {"address": address_to_import},
                                 {"spendable": False})
 
+        if False:  # removaddress is broken and disabled
             # 5. Remove the address from node1
             self.nodes[1].removeaddress(address_to_import)
 
@@ -638,6 +639,7 @@ class WalletTest(BitcoinTestFramework):
             # 8. Re-import the address
             self.nodes[1].importaddress(address_to_import)
 
+        if not self.options.descriptors:
             # 9. Import private key of the previously imported address on node1
             priv_key = self.nodes[2].dumpprivkey(address_to_import)
             self.nodes[1].importprivkey(priv_key)
@@ -661,6 +663,7 @@ class WalletTest(BitcoinTestFramework):
             self.nodes[1].importaddress(address_to_import2)
             assert self.nodes[1].getaddressinfo(address_to_import2)["iswatchonly"]
 
+        if False:  # removaddress is broken and disabled
             # Remove the address from node1
             self.nodes[1].removeaddress(address_to_import2)
 
@@ -782,6 +785,12 @@ class WalletTest(BitcoinTestFramework):
         assert not address_info["iswatchonly"]
         assert not address_info["isscript"]
         assert not address_info["ischange"]
+        assert_equal(address_info['use_txids'], [])
+
+        # Test getaddressinfo 'txids' field
+        txid = self.nodes[0].sendtoaddress("mneYUmWYsuk7kySiURxCi3AGxrAqZxLgPZ", 1)
+        address_info = self.nodes[0].getaddressinfo("mneYUmWYsuk7kySiURxCi3AGxrAqZxLgPZ")
+        assert_equal(address_info['use_txids'], [txid])
 
         # Test getaddressinfo 'ischange' field on change address.
         self.nodes[0].generate(1)
